/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

GtkWidget*
create_mainwindow (void)
{
  GtkWidget *mainwindow;
  GtkWidget *vbox1;
  GtkWidget *handlebox1;
  GtkWidget *menubar1;
  GtkWidget *file;
  GtkWidget *file_menu;
  GtkAccelGroup *file_menu_accels;
  GtkWidget *freqlist;
  GtkWidget *modemconfig;
  GtkWidget *selectmodem;
  GtkWidget *audioparams;
  GtkWidget *separator1;
  GtkWidget *quit;
  GtkWidget *audio;
  GtkWidget *audio_menu;
  GtkAccelGroup *audio_menu_accels;
  GtkWidget *spkscope;
  GtkWidget *spkspectrum;
  GtkWidget *micscope;
  GtkWidget *micspectrum;
  GtkWidget *audiodtmf;
  GtkWidget *audiopwrs;
  GtkWidget *expert;
  GtkWidget *expert_menu;
  GtkAccelGroup *expert_menu_accels;
  GtkWidget *terminal;
  GtkWidget *channelwindow;
  GtkWidget *progchmem;
  GtkWidget *help;
  GtkWidget *help_menu;
  GtkAccelGroup *help_menu_accels;
  GtkWidget *about;
  GtkWidget *hbox2;
  GtkWidget *vbox5;
  GtkWidget *frame2;
  GtkWidget *table4;
  GtkObject *rxqrg_adj;
  GtkWidget *rxqrg;
  GtkWidget *label58;
  GtkWidget *label57;
  GtkObject *txqrg_adj;
  GtkWidget *txqrg;
  GtkWidget *label124;
  GtkWidget *label125;
  GtkWidget *frame6;
  GtkWidget *hbox4;
  GtkWidget *stnname;
  GtkWidget *stnnameentry;
  GtkWidget *frame3;
  GtkWidget *hbox3;
  GtkWidget *buttonptt;
  GtkWidget *button1750;
  GtkWidget *labelptt;
  GtkWidget *ledptt;
  GtkWidget *labeldcd;
  GtkWidget *leddcd;
  GtkWidget *frame5;
  GtkWidget *rssi;
  GtkWidget *frame4;
  GtkWidget *rssihistory;
  GtkWidget *statusbar;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  mainwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (mainwindow), "mainwindow", mainwindow);
  gtk_window_set_title (GTK_WINDOW (mainwindow), _("Baycom USB Transceiver Controller"));
  gtk_window_set_wmclass (GTK_WINDOW (mainwindow), "baycomusb", "baycomusb");

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox1);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "vbox1", vbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (mainwindow), vbox1);

  handlebox1 = gtk_handle_box_new ();
  gtk_widget_ref (handlebox1);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "handlebox1", handlebox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (handlebox1);
  gtk_box_pack_start (GTK_BOX (vbox1), handlebox1, FALSE, TRUE, 0);

  menubar1 = gtk_menu_bar_new ();
  gtk_widget_ref (menubar1);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "menubar1", menubar1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menubar1);
  gtk_container_add (GTK_CONTAINER (handlebox1), menubar1);

  file = gtk_menu_item_new_with_label (_("File"));
  gtk_widget_ref (file);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "file", file,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (file);
  gtk_container_add (GTK_CONTAINER (menubar1), file);

  file_menu = gtk_menu_new ();
  gtk_widget_ref (file_menu);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "file_menu", file_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (file), file_menu);
  file_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (file_menu));

  freqlist = gtk_menu_item_new_with_label (_("Frequency List..."));
  gtk_widget_ref (freqlist);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "freqlist", freqlist,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (freqlist);
  gtk_container_add (GTK_CONTAINER (file_menu), freqlist);
  gtk_widget_add_accelerator (freqlist, "activate", accel_group,
                              GDK_F, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  modemconfig = gtk_menu_item_new_with_label (_("Modem Configuration..."));
  gtk_widget_ref (modemconfig);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "modemconfig", modemconfig,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (modemconfig);
  gtk_container_add (GTK_CONTAINER (file_menu), modemconfig);
  gtk_widget_add_accelerator (modemconfig, "activate", accel_group,
                              GDK_C, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  selectmodem = gtk_menu_item_new_with_label (_("Select Modem..."));
  gtk_widget_ref (selectmodem);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "selectmodem", selectmodem,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (selectmodem);
  gtk_container_add (GTK_CONTAINER (file_menu), selectmodem);
  gtk_widget_add_accelerator (selectmodem, "activate", accel_group,
                              GDK_S, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  audioparams = gtk_menu_item_new_with_label (_("Settings..."));
  gtk_widget_ref (audioparams);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "audioparams", audioparams,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audioparams);
  gtk_container_add (GTK_CONTAINER (file_menu), audioparams);
  gtk_widget_add_accelerator (audioparams, "activate", accel_group,
                              GDK_Z, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  separator1 = gtk_menu_item_new ();
  gtk_widget_ref (separator1);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "separator1", separator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator1);
  gtk_container_add (GTK_CONTAINER (file_menu), separator1);
  gtk_widget_set_sensitive (separator1, FALSE);

  quit = gtk_menu_item_new_with_label (_("Quit"));
  gtk_widget_ref (quit);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "quit", quit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (quit);
  gtk_container_add (GTK_CONTAINER (file_menu), quit);
  gtk_widget_add_accelerator (quit, "activate", accel_group,
                              GDK_Q, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  audio = gtk_menu_item_new_with_label (_("Audio"));
  gtk_widget_ref (audio);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "audio", audio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audio);
  gtk_container_add (GTK_CONTAINER (menubar1), audio);

  audio_menu = gtk_menu_new ();
  gtk_widget_ref (audio_menu);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "audio_menu", audio_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (audio), audio_menu);
  audio_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (audio_menu));

  spkscope = gtk_menu_item_new_with_label (_("Speaker Scope"));
  gtk_widget_ref (spkscope);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "spkscope", spkscope,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spkscope);
  gtk_container_add (GTK_CONTAINER (audio_menu), spkscope);

  spkspectrum = gtk_menu_item_new_with_label (_("Speaker Spectrum"));
  gtk_widget_ref (spkspectrum);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "spkspectrum", spkspectrum,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spkspectrum);
  gtk_container_add (GTK_CONTAINER (audio_menu), spkspectrum);

  micscope = gtk_menu_item_new_with_label (_("Microphone Scope"));
  gtk_widget_ref (micscope);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "micscope", micscope,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (micscope);
  gtk_container_add (GTK_CONTAINER (audio_menu), micscope);

  micspectrum = gtk_menu_item_new_with_label (_("Microphone Spectrum"));
  gtk_widget_ref (micspectrum);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "micspectrum", micspectrum,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (micspectrum);
  gtk_container_add (GTK_CONTAINER (audio_menu), micspectrum);

  audiodtmf = gtk_menu_item_new_with_label (_("DTMF"));
  gtk_widget_ref (audiodtmf);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "audiodtmf", audiodtmf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audiodtmf);
  gtk_container_add (GTK_CONTAINER (audio_menu), audiodtmf);

  audiopwrs = gtk_menu_item_new_with_label (_("Signal Levels"));
  gtk_widget_ref (audiopwrs);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "audiopwrs", audiopwrs,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audiopwrs);
  gtk_container_add (GTK_CONTAINER (audio_menu), audiopwrs);

  expert = gtk_menu_item_new_with_label (_("Expert"));
  gtk_widget_ref (expert);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "expert", expert,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (expert);
  gtk_container_add (GTK_CONTAINER (menubar1), expert);

  expert_menu = gtk_menu_new ();
  gtk_widget_ref (expert_menu);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "expert_menu", expert_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (expert), expert_menu);
  expert_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (expert_menu));

  terminal = gtk_menu_item_new_with_label (_("Terminal"));
  gtk_widget_ref (terminal);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "terminal", terminal,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (terminal);
  gtk_container_add (GTK_CONTAINER (expert_menu), terminal);
  gtk_tooltips_set_tip (tooltips, terminal, _("Open Terminal Window"), NULL);
  gtk_widget_add_accelerator (terminal, "activate", accel_group,
                              GDK_T, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  channelwindow = gtk_menu_item_new_with_label (_("Channel Window"));
  gtk_widget_ref (channelwindow);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "channelwindow", channelwindow,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (channelwindow);
  gtk_container_add (GTK_CONTAINER (expert_menu), channelwindow);
  gtk_widget_add_accelerator (channelwindow, "activate", accel_group,
                              GDK_M, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  progchmem = gtk_menu_item_new_with_label (_("Program Channel Memory"));
  gtk_widget_ref (progchmem);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "progchmem", progchmem,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progchmem);
  gtk_container_add (GTK_CONTAINER (expert_menu), progchmem);
  gtk_widget_add_accelerator (progchmem, "activate", accel_group,
                              GDK_P, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  help = gtk_menu_item_new_with_label (_("Help"));
  gtk_widget_ref (help);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "help", help,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (help);
  gtk_container_add (GTK_CONTAINER (menubar1), help);
  gtk_menu_item_right_justify (GTK_MENU_ITEM (help));

  help_menu = gtk_menu_new ();
  gtk_widget_ref (help_menu);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "help_menu", help_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (help), help_menu);
  help_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (help_menu));

  about = gtk_menu_item_new_with_label (_("About"));
  gtk_widget_ref (about);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "about", about,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (about);
  gtk_container_add (GTK_CONTAINER (help_menu), about);
  gtk_widget_add_accelerator (about, "activate", accel_group,
                              GDK_A, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox2, TRUE, TRUE, 0);

  vbox5 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox5);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "vbox5", vbox5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox5);
  gtk_box_pack_start (GTK_BOX (hbox2), vbox5, TRUE, TRUE, 0);

  frame2 = gtk_frame_new (_("QRG"));
  gtk_widget_ref (frame2);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "frame2", frame2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (vbox5), frame2, TRUE, TRUE, 0);

  table4 = gtk_table_new (2, 3, FALSE);
  gtk_widget_ref (table4);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "table4", table4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table4);
  gtk_container_add (GTK_CONTAINER (frame2), table4);

  rxqrg_adj = gtk_adjustment_new (0, 0, 99999, 0.0125, 1, 1);
  rxqrg = gtk_spin_button_new (GTK_ADJUSTMENT (rxqrg_adj), 1, 4);
  gtk_widget_ref (rxqrg);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "rxqrg", rxqrg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (rxqrg);
  gtk_table_attach (GTK_TABLE (table4), rxqrg, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 4);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (rxqrg), TRUE);

  label58 = gtk_label_new (_("TX"));
  gtk_widget_ref (label58);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "label58", label58,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label58);
  gtk_table_attach (GTK_TABLE (table4), label58, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label58), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label58), 5, 0);

  label57 = gtk_label_new (_("RX"));
  gtk_widget_ref (label57);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "label57", label57,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label57);
  gtk_table_attach (GTK_TABLE (table4), label57, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label57), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label57), 5, 0);

  txqrg_adj = gtk_adjustment_new (0, 0, 99999, 0.0125, 1, 1);
  txqrg = gtk_spin_button_new (GTK_ADJUSTMENT (txqrg_adj), 1, 4);
  gtk_widget_ref (txqrg);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "txqrg", txqrg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txqrg);
  gtk_table_attach (GTK_TABLE (table4), txqrg, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 4);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (txqrg), TRUE);

  label124 = gtk_label_new (_("MHz"));
  gtk_widget_ref (label124);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "label124", label124,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label124);
  gtk_table_attach (GTK_TABLE (table4), label124, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label124), 5, 0);

  label125 = gtk_label_new (_("MHz"));
  gtk_widget_ref (label125);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "label125", label125,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label125);
  gtk_table_attach (GTK_TABLE (table4), label125, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label125), 5, 0);

  frame6 = gtk_frame_new (_("Station Name"));
  gtk_widget_ref (frame6);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "frame6", frame6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame6);
  gtk_box_pack_start (GTK_BOX (vbox5), frame6, TRUE, TRUE, 0);

  hbox4 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox4);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "hbox4", hbox4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (frame6), hbox4);

  stnname = gtk_combo_new ();
  gtk_widget_ref (stnname);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "stnname", stnname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (stnname);
  gtk_box_pack_start (GTK_BOX (hbox4), stnname, TRUE, TRUE, 0);

  stnnameentry = GTK_COMBO (stnname)->entry;
  gtk_widget_ref (stnnameentry);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "stnnameentry", stnnameentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (stnnameentry);
  gtk_entry_set_editable (GTK_ENTRY (stnnameentry), FALSE);

  frame3 = gtk_frame_new (_("Status"));
  gtk_widget_ref (frame3);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "frame3", frame3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame3);
  gtk_box_pack_start (GTK_BOX (vbox5), frame3, TRUE, TRUE, 0);

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox3);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "hbox3", hbox3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox3);
  gtk_container_add (GTK_CONTAINER (frame3), hbox3);

  buttonptt = gtk_toggle_button_new_with_label (_("PTT"));
  gtk_widget_ref (buttonptt);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "buttonptt", buttonptt,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttonptt);
  gtk_box_pack_start (GTK_BOX (hbox3), buttonptt, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (buttonptt), 6);

  button1750 = gtk_button_new_with_label (_("1750"));
  gtk_widget_ref (button1750);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "button1750", button1750,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button1750);
  gtk_box_pack_start (GTK_BOX (hbox3), button1750, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button1750), 6);

  labelptt = gtk_label_new (_("PTT"));
  gtk_widget_ref (labelptt);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "labelptt", labelptt,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (labelptt);
  gtk_box_pack_start (GTK_BOX (hbox3), labelptt, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (labelptt), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (labelptt), 5, 0);

  ledptt = create_led_pixmap ("ledptt", NULL, NULL, 0, 0);
  gtk_widget_ref (ledptt);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "ledptt", ledptt,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ledptt);
  gtk_box_pack_start (GTK_BOX (hbox3), ledptt, FALSE, TRUE, 4);
  GTK_WIDGET_UNSET_FLAGS (ledptt, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (ledptt, GTK_CAN_DEFAULT);

  labeldcd = gtk_label_new (_("DCD"));
  gtk_widget_ref (labeldcd);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "labeldcd", labeldcd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (labeldcd);
  gtk_box_pack_start (GTK_BOX (hbox3), labeldcd, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (labeldcd), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (labeldcd), 5, 0);

  leddcd = create_led_pixmap ("leddcd", NULL, NULL, 0, 0);
  gtk_widget_ref (leddcd);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "leddcd", leddcd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (leddcd);
  gtk_box_pack_start (GTK_BOX (hbox3), leddcd, FALSE, TRUE, 4);
  GTK_WIDGET_UNSET_FLAGS (leddcd, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (leddcd, GTK_CAN_DEFAULT);

  frame5 = gtk_frame_new (_("S"));
  gtk_widget_ref (frame5);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "frame5", frame5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame5);
  gtk_box_pack_start (GTK_BOX (hbox2), frame5, FALSE, FALSE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame5), 0.5, 0.5);

  rssi = gtk_progress_bar_new ();
  gtk_widget_ref (rssi);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "rssi", rssi,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (rssi);
  gtk_container_add (GTK_CONTAINER (frame5), rssi);
  gtk_progress_configure (GTK_PROGRESS (rssi), 255, 255, 255);
  gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (rssi), GTK_PROGRESS_BOTTOM_TO_TOP);
  gtk_progress_set_show_text (GTK_PROGRESS (rssi), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (rssi), _("%v"));

  frame4 = gtk_frame_new (_("S-Meter History"));
  gtk_widget_ref (frame4);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "frame4", frame4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame4);
  gtk_box_pack_start (GTK_BOX (vbox1), frame4, FALSE, FALSE, 0);

  rssihistory = signalhistory_new ("rssihistory", NULL, NULL, 0, 0);
  gtk_widget_ref (rssihistory);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "rssihistory", rssihistory,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (rssihistory);
  gtk_container_add (GTK_CONTAINER (frame4), rssihistory);
  gtk_widget_set_usize (rssihistory, 256, 64);
  GTK_WIDGET_UNSET_FLAGS (rssihistory, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (rssihistory, GTK_CAN_DEFAULT);

  statusbar = gtk_statusbar_new ();
  gtk_widget_ref (statusbar);
  gtk_object_set_data_full (GTK_OBJECT (mainwindow), "statusbar", statusbar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (statusbar);
  gtk_box_pack_start (GTK_BOX (vbox1), statusbar, FALSE, FALSE, 0);

  gtk_signal_connect (GTK_OBJECT (mainwindow), "destroy_event",
                      GTK_SIGNAL_FUNC (on_mainwindow_destroy_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (mainwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_mainwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (freqlist), "activate",
                      GTK_SIGNAL_FUNC (on_freqlist_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (modemconfig), "activate",
                      GTK_SIGNAL_FUNC (on_modemconfig_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (selectmodem), "activate",
                      GTK_SIGNAL_FUNC (on_selectmodem_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (audioparams), "activate",
                      GTK_SIGNAL_FUNC (on_audioparams_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (quit), "activate",
                      GTK_SIGNAL_FUNC (on_quit_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (spkscope), "activate",
                      GTK_SIGNAL_FUNC (on_spkscope_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (spkspectrum), "activate",
                      GTK_SIGNAL_FUNC (on_spkspectrum_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (micscope), "activate",
                      GTK_SIGNAL_FUNC (on_micscope_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (micspectrum), "activate",
                      GTK_SIGNAL_FUNC (on_micspectrum_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (audiodtmf), "activate",
                      GTK_SIGNAL_FUNC (on_audiodtmf_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (audiopwrs), "activate",
                      GTK_SIGNAL_FUNC (on_audiopwrs_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (terminal), "activate",
                      GTK_SIGNAL_FUNC (on_terminal_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (channelwindow), "activate",
                      GTK_SIGNAL_FUNC (on_channelwindow_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progchmem), "activate",
                      GTK_SIGNAL_FUNC (on_progchmem_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (about), "activate",
                      GTK_SIGNAL_FUNC (on_about_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (rxqrg), "changed",
                      GTK_SIGNAL_FUNC (on_qrg_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (txqrg), "changed",
                      GTK_SIGNAL_FUNC (on_qrg_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (stnnameentry), "changed",
                      GTK_SIGNAL_FUNC (on_stn_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttonptt), "toggled",
                      GTK_SIGNAL_FUNC (on_buttonptt_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button1750), "pressed",
                      GTK_SIGNAL_FUNC (on_button1750_pressed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button1750), "released",
                      GTK_SIGNAL_FUNC (on_button1750_released),
                      NULL);

  gtk_object_set_data (GTK_OBJECT (mainwindow), "tooltips", tooltips);

  gtk_window_add_accel_group (GTK_WINDOW (mainwindow), accel_group);

  return mainwindow;
}

GtkWidget*
create_aboutwindow (void)
{
  GtkWidget *aboutwindow;
  GtkWidget *dialog_vbox1;
  GtkWidget *frame1;
  GtkWidget *vbox4;
  GtkWidget *label13;
  GtkWidget *label14;
  GtkWidget *dialog_action_area1;
  GtkWidget *hbuttonbox1;
  GtkWidget *aboutok;

  aboutwindow = gtk_dialog_new ();
  gtk_object_set_data (GTK_OBJECT (aboutwindow), "aboutwindow", aboutwindow);
  gtk_window_set_title (GTK_WINDOW (aboutwindow), _("About Baycom USB Transceiver Controller"));
  gtk_window_set_policy (GTK_WINDOW (aboutwindow), TRUE, TRUE, FALSE);
  gtk_window_set_wmclass (GTK_WINDOW (aboutwindow), "baycomusb", "baycomusb");

  dialog_vbox1 = GTK_DIALOG (aboutwindow)->vbox;
  gtk_object_set_data (GTK_OBJECT (aboutwindow), "dialog_vbox1", dialog_vbox1);
  gtk_widget_show (dialog_vbox1);

  frame1 = gtk_frame_new (_("Baycom USB Transceiver Controller"));
  gtk_widget_ref (frame1);
  gtk_object_set_data_full (GTK_OBJECT (aboutwindow), "frame1", frame1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame1);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), frame1, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame1), 6);
  gtk_frame_set_label_align (GTK_FRAME (frame1), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_ETCHED_OUT);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox4);
  gtk_object_set_data_full (GTK_OBJECT (aboutwindow), "vbox4", vbox4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox4);
  gtk_container_add (GTK_CONTAINER (frame1), vbox4);

  label13 = gtk_label_new (_("Copyright 2000-2001"));
  gtk_widget_ref (label13);
  gtk_object_set_data_full (GTK_OBJECT (aboutwindow), "label13", label13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label13);
  gtk_box_pack_start (GTK_BOX (vbox4), label13, TRUE, TRUE, 0);

  label14 = gtk_label_new (_("Thomas Sailer, HB9JNX"));
  gtk_widget_ref (label14);
  gtk_object_set_data_full (GTK_OBJECT (aboutwindow), "label14", label14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label14);
  gtk_box_pack_start (GTK_BOX (vbox4), label14, TRUE, TRUE, 0);

  dialog_action_area1 = GTK_DIALOG (aboutwindow)->action_area;
  gtk_object_set_data (GTK_OBJECT (aboutwindow), "dialog_action_area1", dialog_action_area1);
  gtk_widget_show (dialog_action_area1);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area1), 10);

  hbuttonbox1 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox1);
  gtk_object_set_data_full (GTK_OBJECT (aboutwindow), "hbuttonbox1", hbuttonbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox1);
  gtk_box_pack_start (GTK_BOX (dialog_action_area1), hbuttonbox1, FALSE, FALSE, 0);

  aboutok = gtk_button_new_with_label (_("Ok"));
  gtk_widget_ref (aboutok);
  gtk_object_set_data_full (GTK_OBJECT (aboutwindow), "aboutok", aboutok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (aboutok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox1), aboutok);
  GTK_WIDGET_SET_FLAGS (aboutok, GTK_CAN_DEFAULT);

  return aboutwindow;
}

GtkWidget*
create_errordialog (void)
{
  GtkWidget *errordialog;
  GtkWidget *dialog_vbox3;
  GtkWidget *errorlabel;
  GtkWidget *dialog_action_area3;
  GtkWidget *hbuttonbox3;
  GtkWidget *errorok;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  errordialog = gtk_dialog_new ();
  gtk_object_set_data (GTK_OBJECT (errordialog), "errordialog", errordialog);
  gtk_window_set_title (GTK_WINDOW (errordialog), _("Error"));
  gtk_window_set_modal (GTK_WINDOW (errordialog), TRUE);
  gtk_window_set_policy (GTK_WINDOW (errordialog), TRUE, TRUE, FALSE);
  gtk_window_set_wmclass (GTK_WINDOW (errordialog), "baycomusb", "baycomusb");

  dialog_vbox3 = GTK_DIALOG (errordialog)->vbox;
  gtk_object_set_data (GTK_OBJECT (errordialog), "dialog_vbox3", dialog_vbox3);
  gtk_widget_show (dialog_vbox3);

  errorlabel = gtk_label_new (_("Error"));
  gtk_widget_ref (errorlabel);
  gtk_object_set_data_full (GTK_OBJECT (errordialog), "errorlabel", errorlabel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (errorlabel);
  gtk_box_pack_start (GTK_BOX (dialog_vbox3), errorlabel, TRUE, TRUE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (errorlabel), TRUE);
  gtk_misc_set_padding (GTK_MISC (errorlabel), 6, 6);

  dialog_action_area3 = GTK_DIALOG (errordialog)->action_area;
  gtk_object_set_data (GTK_OBJECT (errordialog), "dialog_action_area3", dialog_action_area3);
  gtk_widget_show (dialog_action_area3);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area3), 10);

  hbuttonbox3 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox3);
  gtk_object_set_data_full (GTK_OBJECT (errordialog), "hbuttonbox3", hbuttonbox3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox3);
  gtk_box_pack_start (GTK_BOX (dialog_action_area3), hbuttonbox3, TRUE, TRUE, 0);

  errorok = gtk_button_new_with_label (_("OK"));
  gtk_widget_ref (errorok);
  gtk_object_set_data_full (GTK_OBJECT (errordialog), "errorok", errorok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (errorok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), errorok);
  GTK_WIDGET_SET_FLAGS (errorok, GTK_CAN_DEFAULT);
  gtk_widget_add_accelerator (errorok, "clicked", accel_group,
                              GDK_Return, 0,
                              GTK_ACCEL_VISIBLE);

  gtk_window_add_accel_group (GTK_WINDOW (errordialog), accel_group);

  return errordialog;
}

GtkWidget*
create_terminalwindow (void)
{
  GtkWidget *terminalwindow;
  GtkWidget *scrolledwindow1;
  GtkWidget *text;

  terminalwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (terminalwindow), "terminalwindow", terminalwindow);
  gtk_window_set_title (GTK_WINDOW (terminalwindow), _("T7F Terminal"));
  gtk_window_set_default_size (GTK_WINDOW (terminalwindow), 250, 150);
  gtk_window_set_policy (GTK_WINDOW (terminalwindow), TRUE, TRUE, FALSE);
  gtk_window_set_wmclass (GTK_WINDOW (terminalwindow), "baycomusb", "baycomusb");

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (scrolledwindow1);
  gtk_object_set_data_full (GTK_OBJECT (terminalwindow), "scrolledwindow1", scrolledwindow1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow1);
  gtk_container_add (GTK_CONTAINER (terminalwindow), scrolledwindow1);

  text = gtk_text_new (NULL, NULL);
  gtk_widget_ref (text);
  gtk_object_set_data_full (GTK_OBJECT (terminalwindow), "text", text,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (text);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), text);
  gtk_widget_set_events (text, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);

  gtk_signal_connect (GTK_OBJECT (terminalwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_terminalwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (text), "key_press_event",
                      GTK_SIGNAL_FUNC (on_text_key_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (text), "key_release_event",
                      GTK_SIGNAL_FUNC (on_text_key_release_event),
                      NULL);

  gtk_widget_grab_focus (text);
  return terminalwindow;
}

GtkWidget*
create_chmemorywindow (void)
{
  GtkWidget *chmemorywindow;
  GtkWidget *table5;
  GtkWidget *label61;
  GtkWidget *label62;
  GtkWidget *label63;
  GtkWidget *label64;
  GtkWidget *label65;
  GtkWidget *label66;
  GtkWidget *label67;
  GtkWidget *label68;
  GtkWidget *label69;
  GtkWidget *label70;
  GtkWidget *label71;
  GtkWidget *label73;
  GtkWidget *label72;
  GtkWidget *label77;
  GtkWidget *label76;
  GtkWidget *label75;
  GtkWidget *label74;
  GtkWidget *ch0a;
  GtkWidget *ch1a;
  GtkWidget *ch2a;
  GtkWidget *ch3a;
  GtkWidget *ch4a;
  GtkWidget *ch5a;
  GtkWidget *ch6a;
  GtkWidget *ch7a;
  GtkWidget *ch8a;
  GtkWidget *ch9a;
  GtkWidget *ch9b;
  GtkWidget *ch8b;
  GtkWidget *ch7b;
  GtkWidget *ch6b;
  GtkWidget *ch5b;
  GtkWidget *ch4b;
  GtkWidget *ch3b;
  GtkWidget *ch2b;
  GtkWidget *ch1b;
  GtkWidget *ch0b;
  GtkWidget *ch0c;
  GtkWidget *ch1c;
  GtkWidget *ch2c;
  GtkWidget *ch3c;
  GtkWidget *ch4c;
  GtkWidget *ch5c;
  GtkWidget *ch6c;
  GtkWidget *ch7c;
  GtkWidget *ch8c;
  GtkWidget *ch9c;
  GtkWidget *ch0d;
  GtkWidget *ch1d;
  GtkWidget *ch2d;
  GtkWidget *ch3d;
  GtkWidget *ch4d;
  GtkWidget *ch5d;
  GtkWidget *ch6d;
  GtkWidget *ch7d;
  GtkWidget *ch8d;
  GtkWidget *ch9d;

  chmemorywindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (chmemorywindow), "chmemorywindow", chmemorywindow);
  gtk_window_set_title (GTK_WINDOW (chmemorywindow), _("T7F Channel Memory"));
  gtk_window_set_wmclass (GTK_WINDOW (chmemorywindow), "baycomusb", "baycomusb");

  table5 = gtk_table_new (12, 5, FALSE);
  gtk_widget_ref (table5);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "table5", table5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table5);
  gtk_container_add (GTK_CONTAINER (chmemorywindow), table5);

  label61 = gtk_label_new (_("Channel"));
  gtk_widget_ref (label61);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label61", label61,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label61);
  gtk_table_attach (GTK_TABLE (table5), label61, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label61), 5, 0);

  label62 = gtk_label_new (_("0"));
  gtk_widget_ref (label62);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label62", label62,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label62);
  gtk_table_attach (GTK_TABLE (table5), label62, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label63 = gtk_label_new (_("1"));
  gtk_widget_ref (label63);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label63", label63,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label63);
  gtk_table_attach (GTK_TABLE (table5), label63, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label64 = gtk_label_new (_("2"));
  gtk_widget_ref (label64);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label64", label64,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label64);
  gtk_table_attach (GTK_TABLE (table5), label64, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label65 = gtk_label_new (_("3"));
  gtk_widget_ref (label65);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label65", label65,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label65);
  gtk_table_attach (GTK_TABLE (table5), label65, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label66 = gtk_label_new (_("4"));
  gtk_widget_ref (label66);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label66", label66,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label66);
  gtk_table_attach (GTK_TABLE (table5), label66, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label67 = gtk_label_new (_("5"));
  gtk_widget_ref (label67);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label67", label67,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label67);
  gtk_table_attach (GTK_TABLE (table5), label67, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label68 = gtk_label_new (_("6"));
  gtk_widget_ref (label68);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label68", label68,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label68);
  gtk_table_attach (GTK_TABLE (table5), label68, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label69 = gtk_label_new (_("7"));
  gtk_widget_ref (label69);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label69", label69,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label69);
  gtk_table_attach (GTK_TABLE (table5), label69, 0, 1, 9, 10,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label70 = gtk_label_new (_("8"));
  gtk_widget_ref (label70);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label70", label70,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label70);
  gtk_table_attach (GTK_TABLE (table5), label70, 0, 1, 10, 11,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label71 = gtk_label_new (_("9"));
  gtk_widget_ref (label71);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label71", label71,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label71);
  gtk_table_attach (GTK_TABLE (table5), label71, 0, 1, 11, 12,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label73 = gtk_label_new (_("25kHz Raster"));
  gtk_widget_ref (label73);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label73", label73,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label73);
  gtk_table_attach (GTK_TABLE (table5), label73, 3, 5, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label73), 5, 0);

  label72 = gtk_label_new (_("12.5kHz Raster"));
  gtk_widget_ref (label72);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label72", label72,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label72);
  gtk_table_attach (GTK_TABLE (table5), label72, 1, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label72), 5, 0);

  label77 = gtk_label_new (_("TX"));
  gtk_widget_ref (label77);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label77", label77,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label77);
  gtk_table_attach (GTK_TABLE (table5), label77, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label76 = gtk_label_new (_("RX"));
  gtk_widget_ref (label76);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label76", label76,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label76);
  gtk_table_attach (GTK_TABLE (table5), label76, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label75 = gtk_label_new (_("TX"));
  gtk_widget_ref (label75);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label75", label75,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label75);
  gtk_table_attach (GTK_TABLE (table5), label75, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label74 = gtk_label_new (_("RX"));
  gtk_widget_ref (label74);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "label74", label74,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label74);
  gtk_table_attach (GTK_TABLE (table5), label74, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  ch0a = gtk_label_new (_("-"));
  gtk_widget_ref (ch0a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch0a", ch0a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch0a);
  gtk_table_attach (GTK_TABLE (table5), ch0a, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch0a), 5, 0);

  ch1a = gtk_label_new (_("-"));
  gtk_widget_ref (ch1a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch1a", ch1a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch1a);
  gtk_table_attach (GTK_TABLE (table5), ch1a, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch1a), 5, 0);

  ch2a = gtk_label_new (_("-"));
  gtk_widget_ref (ch2a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch2a", ch2a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch2a);
  gtk_table_attach (GTK_TABLE (table5), ch2a, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch2a), 5, 0);

  ch3a = gtk_label_new (_("-"));
  gtk_widget_ref (ch3a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch3a", ch3a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch3a);
  gtk_table_attach (GTK_TABLE (table5), ch3a, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch3a), 5, 0);

  ch4a = gtk_label_new (_("-"));
  gtk_widget_ref (ch4a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch4a", ch4a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch4a);
  gtk_table_attach (GTK_TABLE (table5), ch4a, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch4a), 5, 0);

  ch5a = gtk_label_new (_("-"));
  gtk_widget_ref (ch5a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch5a", ch5a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch5a);
  gtk_table_attach (GTK_TABLE (table5), ch5a, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch5a), 5, 0);

  ch6a = gtk_label_new (_("-"));
  gtk_widget_ref (ch6a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch6a", ch6a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch6a);
  gtk_table_attach (GTK_TABLE (table5), ch6a, 1, 2, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch6a), 5, 0);

  ch7a = gtk_label_new (_("-"));
  gtk_widget_ref (ch7a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch7a", ch7a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch7a);
  gtk_table_attach (GTK_TABLE (table5), ch7a, 1, 2, 9, 10,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch7a), 5, 0);

  ch8a = gtk_label_new (_("-"));
  gtk_widget_ref (ch8a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch8a", ch8a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch8a);
  gtk_table_attach (GTK_TABLE (table5), ch8a, 1, 2, 10, 11,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch8a), 5, 0);

  ch9a = gtk_label_new (_("-"));
  gtk_widget_ref (ch9a);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch9a", ch9a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch9a);
  gtk_table_attach (GTK_TABLE (table5), ch9a, 1, 2, 11, 12,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch9a), 5, 0);

  ch9b = gtk_label_new (_("-"));
  gtk_widget_ref (ch9b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch9b", ch9b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch9b);
  gtk_table_attach (GTK_TABLE (table5), ch9b, 2, 3, 11, 12,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch9b), 5, 0);

  ch8b = gtk_label_new (_("-"));
  gtk_widget_ref (ch8b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch8b", ch8b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch8b);
  gtk_table_attach (GTK_TABLE (table5), ch8b, 2, 3, 10, 11,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch8b), 5, 0);

  ch7b = gtk_label_new (_("-"));
  gtk_widget_ref (ch7b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch7b", ch7b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch7b);
  gtk_table_attach (GTK_TABLE (table5), ch7b, 2, 3, 9, 10,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch7b), 5, 0);

  ch6b = gtk_label_new (_("-"));
  gtk_widget_ref (ch6b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch6b", ch6b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch6b);
  gtk_table_attach (GTK_TABLE (table5), ch6b, 2, 3, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch6b), 5, 0);

  ch5b = gtk_label_new (_("-"));
  gtk_widget_ref (ch5b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch5b", ch5b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch5b);
  gtk_table_attach (GTK_TABLE (table5), ch5b, 2, 3, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch5b), 5, 0);

  ch4b = gtk_label_new (_("-"));
  gtk_widget_ref (ch4b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch4b", ch4b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch4b);
  gtk_table_attach (GTK_TABLE (table5), ch4b, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch4b), 5, 0);

  ch3b = gtk_label_new (_("-"));
  gtk_widget_ref (ch3b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch3b", ch3b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch3b);
  gtk_table_attach (GTK_TABLE (table5), ch3b, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch3b), 5, 0);

  ch2b = gtk_label_new (_("-"));
  gtk_widget_ref (ch2b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch2b", ch2b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch2b);
  gtk_table_attach (GTK_TABLE (table5), ch2b, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch2b), 5, 0);

  ch1b = gtk_label_new (_("-"));
  gtk_widget_ref (ch1b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch1b", ch1b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch1b);
  gtk_table_attach (GTK_TABLE (table5), ch1b, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch1b), 5, 0);

  ch0b = gtk_label_new (_("-"));
  gtk_widget_ref (ch0b);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch0b", ch0b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch0b);
  gtk_table_attach (GTK_TABLE (table5), ch0b, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch0b), 5, 0);

  ch0c = gtk_label_new (_("-"));
  gtk_widget_ref (ch0c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch0c", ch0c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch0c);
  gtk_table_attach (GTK_TABLE (table5), ch0c, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch0c), 5, 0);

  ch1c = gtk_label_new (_("-"));
  gtk_widget_ref (ch1c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch1c", ch1c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch1c);
  gtk_table_attach (GTK_TABLE (table5), ch1c, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch1c), 5, 0);

  ch2c = gtk_label_new (_("-"));
  gtk_widget_ref (ch2c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch2c", ch2c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch2c);
  gtk_table_attach (GTK_TABLE (table5), ch2c, 3, 4, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch2c), 5, 0);

  ch3c = gtk_label_new (_("-"));
  gtk_widget_ref (ch3c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch3c", ch3c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch3c);
  gtk_table_attach (GTK_TABLE (table5), ch3c, 3, 4, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch3c), 5, 0);

  ch4c = gtk_label_new (_("-"));
  gtk_widget_ref (ch4c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch4c", ch4c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch4c);
  gtk_table_attach (GTK_TABLE (table5), ch4c, 3, 4, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch4c), 5, 0);

  ch5c = gtk_label_new (_("-"));
  gtk_widget_ref (ch5c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch5c", ch5c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch5c);
  gtk_table_attach (GTK_TABLE (table5), ch5c, 3, 4, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch5c), 5, 0);

  ch6c = gtk_label_new (_("-"));
  gtk_widget_ref (ch6c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch6c", ch6c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch6c);
  gtk_table_attach (GTK_TABLE (table5), ch6c, 3, 4, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch6c), 5, 0);

  ch7c = gtk_label_new (_("-"));
  gtk_widget_ref (ch7c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch7c", ch7c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch7c);
  gtk_table_attach (GTK_TABLE (table5), ch7c, 3, 4, 9, 10,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch7c), 5, 0);

  ch8c = gtk_label_new (_("-"));
  gtk_widget_ref (ch8c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch8c", ch8c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch8c);
  gtk_table_attach (GTK_TABLE (table5), ch8c, 3, 4, 10, 11,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch8c), 5, 0);

  ch9c = gtk_label_new (_("-"));
  gtk_widget_ref (ch9c);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch9c", ch9c,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch9c);
  gtk_table_attach (GTK_TABLE (table5), ch9c, 3, 4, 11, 12,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch9c), 5, 0);

  ch0d = gtk_label_new (_("-"));
  gtk_widget_ref (ch0d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch0d", ch0d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch0d);
  gtk_table_attach (GTK_TABLE (table5), ch0d, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch0d), 5, 0);

  ch1d = gtk_label_new (_("-"));
  gtk_widget_ref (ch1d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch1d", ch1d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch1d);
  gtk_table_attach (GTK_TABLE (table5), ch1d, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch1d), 5, 0);

  ch2d = gtk_label_new (_("-"));
  gtk_widget_ref (ch2d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch2d", ch2d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch2d);
  gtk_table_attach (GTK_TABLE (table5), ch2d, 4, 5, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch2d), 5, 0);

  ch3d = gtk_label_new (_("-"));
  gtk_widget_ref (ch3d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch3d", ch3d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch3d);
  gtk_table_attach (GTK_TABLE (table5), ch3d, 4, 5, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch3d), 5, 0);

  ch4d = gtk_label_new (_("-"));
  gtk_widget_ref (ch4d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch4d", ch4d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch4d);
  gtk_table_attach (GTK_TABLE (table5), ch4d, 4, 5, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch4d), 5, 0);

  ch5d = gtk_label_new (_("-"));
  gtk_widget_ref (ch5d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch5d", ch5d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch5d);
  gtk_table_attach (GTK_TABLE (table5), ch5d, 4, 5, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch5d), 5, 0);

  ch6d = gtk_label_new (_("-"));
  gtk_widget_ref (ch6d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch6d", ch6d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch6d);
  gtk_table_attach (GTK_TABLE (table5), ch6d, 4, 5, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch6d), 5, 0);

  ch7d = gtk_label_new (_("-"));
  gtk_widget_ref (ch7d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch7d", ch7d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch7d);
  gtk_table_attach (GTK_TABLE (table5), ch7d, 4, 5, 9, 10,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch7d), 5, 0);

  ch8d = gtk_label_new (_("-"));
  gtk_widget_ref (ch8d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch8d", ch8d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch8d);
  gtk_table_attach (GTK_TABLE (table5), ch8d, 4, 5, 10, 11,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch8d), 5, 0);

  ch9d = gtk_label_new (_("-"));
  gtk_widget_ref (ch9d);
  gtk_object_set_data_full (GTK_OBJECT (chmemorywindow), "ch9d", ch9d,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ch9d);
  gtk_table_attach (GTK_TABLE (table5), ch9d, 4, 5, 11, 12,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (ch9d), 5, 0);

  gtk_signal_connect (GTK_OBJECT (chmemorywindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_chmemorywindow_delete_event),
                      NULL);

  return chmemorywindow;
}

GtkWidget*
create_chprogwindow (void)
{
  GtkWidget *chprogwindow;
  GtkWidget *vbox6;
  GtkWidget *table6;
  GtkObject *rxqrg_adj;
  GtkWidget *rxqrg;
  GtkObject *txqrg_adj;
  GtkWidget *txqrg;
  GtkWidget *label119;
  GtkWidget *label118;
  GtkWidget *label120;
  GtkWidget *label121;
  GtkObject *channel_adj;
  GtkWidget *channel;
  GtkWidget *raster;
  GtkWidget *label123;
  GtkWidget *label122;
  GtkWidget *hbuttonbox4;
  GtkWidget *chprogcancel;
  GtkWidget *chprogok;

  chprogwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (chprogwindow), "chprogwindow", chprogwindow);
  gtk_window_set_title (GTK_WINDOW (chprogwindow), _("Program Channel"));
  gtk_window_set_wmclass (GTK_WINDOW (chprogwindow), "baycomusb", "baycomusb");

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox6);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "vbox6", vbox6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox6);
  gtk_container_add (GTK_CONTAINER (chprogwindow), vbox6);

  table6 = gtk_table_new (4, 3, FALSE);
  gtk_widget_ref (table6);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "table6", table6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table6);
  gtk_box_pack_start (GTK_BOX (vbox6), table6, TRUE, TRUE, 0);

  rxqrg_adj = gtk_adjustment_new (430, 430, 440, 0.025, 1, 1);
  rxqrg = gtk_spin_button_new (GTK_ADJUSTMENT (rxqrg_adj), 1, 4);
  gtk_widget_ref (rxqrg);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "rxqrg", rxqrg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (rxqrg);
  gtk_table_attach (GTK_TABLE (table6), rxqrg, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 3, 3);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (rxqrg), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (rxqrg), TRUE);

  txqrg_adj = gtk_adjustment_new (430, 430, 440, 0.025, 1, 1);
  txqrg = gtk_spin_button_new (GTK_ADJUSTMENT (txqrg_adj), 1, 4);
  gtk_widget_ref (txqrg);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "txqrg", txqrg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txqrg);
  gtk_table_attach (GTK_TABLE (table6), txqrg, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 3, 3);

  label119 = gtk_label_new (_("12.5kHz Raster"));
  gtk_widget_ref (label119);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "label119", label119,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label119);
  gtk_table_attach (GTK_TABLE (table6), label119, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label119), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label119), 5, 0);

  label118 = gtk_label_new (_("Channel"));
  gtk_widget_ref (label118);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "label118", label118,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label118);
  gtk_table_attach (GTK_TABLE (table6), label118, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label118), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label118), 5, 0);

  label120 = gtk_label_new (_("RX Frequency"));
  gtk_widget_ref (label120);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "label120", label120,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label120);
  gtk_table_attach (GTK_TABLE (table6), label120, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label120), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label120), 5, 0);

  label121 = gtk_label_new (_("TX Frequency"));
  gtk_widget_ref (label121);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "label121", label121,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label121);
  gtk_table_attach (GTK_TABLE (table6), label121, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label121), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label121), 5, 0);

  channel_adj = gtk_adjustment_new (0, 0, 9, 1, 1, 1);
  channel = gtk_spin_button_new (GTK_ADJUSTMENT (channel_adj), 1, 0);
  gtk_widget_ref (channel);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "channel", channel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (channel);
  gtk_table_attach (GTK_TABLE (table6), channel, 1, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 3, 3);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (channel), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (channel), TRUE);

  raster = gtk_check_button_new_with_label ("");
  gtk_widget_ref (raster);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "raster", raster,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (raster);
  gtk_table_attach (GTK_TABLE (table6), raster, 1, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 3, 3);

  label123 = gtk_label_new (_("MHz"));
  gtk_widget_ref (label123);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "label123", label123,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label123);
  gtk_table_attach (GTK_TABLE (table6), label123, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label123), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label123), 5, 0);

  label122 = gtk_label_new (_("MHz"));
  gtk_widget_ref (label122);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "label122", label122,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label122);
  gtk_table_attach (GTK_TABLE (table6), label122, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label122), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label122), 5, 0);

  hbuttonbox4 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox4);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "hbuttonbox4", hbuttonbox4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox4);
  gtk_box_pack_start (GTK_BOX (vbox6), hbuttonbox4, FALSE, TRUE, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox4), GTK_BUTTONBOX_SPREAD);

  chprogcancel = gtk_button_new_with_label (_("Cancel"));
  gtk_widget_ref (chprogcancel);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "chprogcancel", chprogcancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chprogcancel);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), chprogcancel);
  GTK_WIDGET_SET_FLAGS (chprogcancel, GTK_CAN_DEFAULT);

  chprogok = gtk_button_new_with_label (_("OK"));
  gtk_widget_ref (chprogok);
  gtk_object_set_data_full (GTK_OBJECT (chprogwindow), "chprogok", chprogok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chprogok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), chprogok);
  GTK_WIDGET_SET_FLAGS (chprogok, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (chprogwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_chprogwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (channel), "changed",
                      GTK_SIGNAL_FUNC (on_chprog_channel_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (raster), "toggled",
                      GTK_SIGNAL_FUNC (on_chprog_raster_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (chprogcancel), "clicked",
                      GTK_SIGNAL_FUNC (on_chprogcancel_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (chprogok), "clicked",
                      GTK_SIGNAL_FUNC (on_chprogok_clicked),
                      NULL);

  return chprogwindow;
}

GtkWidget*
create_freqlistwindow (void)
{
  GtkWidget *freqlistwindow;
  GtkWidget *vbox7;
  GtkWidget *scrolledwindow2;
  GtkWidget *freqlist;
  GtkWidget *label126;
  GtkWidget *label127;
  GtkWidget *label128;
  GtkWidget *label129;
  GtkWidget *hbuttonbox5;
  GtkWidget *buttonset;
  GtkWidget *buttonnew;
  GtkWidget *buttonupdate;
  GtkWidget *buttondelete;

  freqlistwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (freqlistwindow), "freqlistwindow", freqlistwindow);
  gtk_widget_set_usize (freqlistwindow, 600, 200);
  gtk_window_set_title (GTK_WINDOW (freqlistwindow), _("Frequency List"));
  gtk_window_set_wmclass (GTK_WINDOW (freqlistwindow), "baycomusb", "baycomusb");

  vbox7 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox7);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "vbox7", vbox7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox7);
  gtk_container_add (GTK_CONTAINER (freqlistwindow), vbox7);

  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (scrolledwindow2);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "scrolledwindow2", scrolledwindow2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow2);
  gtk_box_pack_start (GTK_BOX (vbox7), scrolledwindow2, TRUE, TRUE, 0);

  freqlist = gtk_clist_new (4);
  gtk_widget_ref (freqlist);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "freqlist", freqlist,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (freqlist);
  gtk_container_add (GTK_CONTAINER (scrolledwindow2), freqlist);
  gtk_clist_set_column_width (GTK_CLIST (freqlist), 0, 303);
  gtk_clist_set_column_width (GTK_CLIST (freqlist), 1, 80);
  gtk_clist_set_column_width (GTK_CLIST (freqlist), 2, 80);
  gtk_clist_set_column_width (GTK_CLIST (freqlist), 3, 80);
  gtk_clist_column_titles_show (GTK_CLIST (freqlist));

  label126 = gtk_label_new (_("Station Name"));
  gtk_widget_ref (label126);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "label126", label126,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label126);
  gtk_clist_set_column_widget (GTK_CLIST (freqlist), 0, label126);

  label127 = gtk_label_new (_("RX"));
  gtk_widget_ref (label127);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "label127", label127,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label127);
  gtk_clist_set_column_widget (GTK_CLIST (freqlist), 1, label127);

  label128 = gtk_label_new (_("TX"));
  gtk_widget_ref (label128);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "label128", label128,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label128);
  gtk_clist_set_column_widget (GTK_CLIST (freqlist), 2, label128);

  label129 = gtk_label_new (_("Mode"));
  gtk_widget_ref (label129);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "label129", label129,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label129);
  gtk_clist_set_column_widget (GTK_CLIST (freqlist), 3, label129);

  hbuttonbox5 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox5);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "hbuttonbox5", hbuttonbox5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox5);
  gtk_box_pack_start (GTK_BOX (vbox7), hbuttonbox5, FALSE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox5), GTK_BUTTONBOX_SPREAD);

  buttonset = gtk_button_new_with_label (_("Set"));
  gtk_widget_ref (buttonset);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "buttonset", buttonset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttonset);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), buttonset);
  GTK_WIDGET_SET_FLAGS (buttonset, GTK_CAN_DEFAULT);

  buttonnew = gtk_button_new_with_label (_("New"));
  gtk_widget_ref (buttonnew);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "buttonnew", buttonnew,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttonnew);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), buttonnew);
  GTK_WIDGET_SET_FLAGS (buttonnew, GTK_CAN_DEFAULT);

  buttonupdate = gtk_button_new_with_label (_("Update"));
  gtk_widget_ref (buttonupdate);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "buttonupdate", buttonupdate,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttonupdate);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), buttonupdate);
  GTK_WIDGET_SET_FLAGS (buttonupdate, GTK_CAN_DEFAULT);

  buttondelete = gtk_button_new_with_label (_("Delete"));
  gtk_widget_ref (buttondelete);
  gtk_object_set_data_full (GTK_OBJECT (freqlistwindow), "buttondelete", buttondelete,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttondelete);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), buttondelete);
  GTK_WIDGET_SET_FLAGS (buttondelete, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (freqlistwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_freqlistwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (freqlist), "select_row",
                      GTK_SIGNAL_FUNC (on_freqlist_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (freqlist), "unselect_row",
                      GTK_SIGNAL_FUNC (on_freqlist_unselect_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttonset), "clicked",
                      GTK_SIGNAL_FUNC (on_freqlistset_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttonnew), "clicked",
                      GTK_SIGNAL_FUNC (on_freqlistnew_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttonupdate), "clicked",
                      GTK_SIGNAL_FUNC (on_freqlistupdate_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttondelete), "clicked",
                      GTK_SIGNAL_FUNC (on_freqlistdelete_clicked),
                      NULL);

  return freqlistwindow;
}

GtkWidget*
create_newstationwindow (void)
{
  GtkWidget *newstationwindow;
  GtkWidget *vbox8;
  GtkWidget *table7;
  GtkWidget *label129;
  GtkWidget *label130;
  GtkWidget *label131;
  GtkWidget *stnname;
  GtkObject *rxqrg_adj;
  GtkWidget *rxqrg;
  GtkObject *txqrg_adj;
  GtkWidget *txqrg;
  GtkWidget *label133;
  GtkWidget *label132;
  GtkWidget *label141;
  GtkWidget *label142;
  GtkWidget *label147;
  GtkWidget *mode;
  GList *mode_items = NULL;
  GtkWidget *modeentry;
  GtkObject *bitraterx_adj;
  GtkWidget *bitraterx;
  GtkObject *bitratetx_adj;
  GtkWidget *bitratetx;
  GtkWidget *label143;
  GtkWidget *label146;
  GtkWidget *hbuttonbox6;
  GtkWidget *buttonok;
  GtkWidget *buttoncancel;

  newstationwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (newstationwindow), "newstationwindow", newstationwindow);
  gtk_window_set_title (GTK_WINDOW (newstationwindow), _("New Station"));
  gtk_window_set_policy (GTK_WINDOW (newstationwindow), FALSE, FALSE, FALSE);
  gtk_window_set_wmclass (GTK_WINDOW (newstationwindow), "baycomusb", "baycomusb");

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox8);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "vbox8", vbox8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox8);
  gtk_container_add (GTK_CONTAINER (newstationwindow), vbox8);

  table7 = gtk_table_new (6, 3, FALSE);
  gtk_widget_ref (table7);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "table7", table7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table7);
  gtk_box_pack_start (GTK_BOX (vbox8), table7, FALSE, TRUE, 0);

  label129 = gtk_label_new (_("RX"));
  gtk_widget_ref (label129);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label129", label129,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label129);
  gtk_table_attach (GTK_TABLE (table7), label129, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label129), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label129), 5, 0);

  label130 = gtk_label_new (_("TX"));
  gtk_widget_ref (label130);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label130", label130,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label130);
  gtk_table_attach (GTK_TABLE (table7), label130, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label130), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label130), 5, 0);

  label131 = gtk_label_new (_("Station Name"));
  gtk_widget_ref (label131);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label131", label131,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label131);
  gtk_table_attach (GTK_TABLE (table7), label131, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label131), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label131), 5, 0);

  stnname = gtk_entry_new ();
  gtk_widget_ref (stnname);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "stnname", stnname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (stnname);
  gtk_table_attach (GTK_TABLE (table7), stnname, 1, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 4);
  gtk_widget_set_usize (stnname, 215, -2);

  rxqrg_adj = gtk_adjustment_new (430, 430, 440, 0.0125, 1, 1);
  rxqrg = gtk_spin_button_new (GTK_ADJUSTMENT (rxqrg_adj), 1, 4);
  gtk_widget_ref (rxqrg);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "rxqrg", rxqrg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (rxqrg);
  gtk_table_attach (GTK_TABLE (table7), rxqrg, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 4);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (rxqrg), TRUE);

  txqrg_adj = gtk_adjustment_new (430, 430, 440, 0.0125, 1, 1);
  txqrg = gtk_spin_button_new (GTK_ADJUSTMENT (txqrg_adj), 1, 4);
  gtk_widget_ref (txqrg);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "txqrg", txqrg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txqrg);
  gtk_table_attach (GTK_TABLE (table7), txqrg, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 4);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (txqrg), TRUE);

  label133 = gtk_label_new (_("MHz"));
  gtk_widget_ref (label133);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label133", label133,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label133);
  gtk_table_attach (GTK_TABLE (table7), label133, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label133), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label133), 5, 0);

  label132 = gtk_label_new (_("MHz"));
  gtk_widget_ref (label132);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label132", label132,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label132);
  gtk_table_attach (GTK_TABLE (table7), label132, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label132), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label132), 5, 0);

  label141 = gtk_label_new (_("Mode"));
  gtk_widget_ref (label141);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label141", label141,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label141);
  gtk_table_attach (GTK_TABLE (table7), label141, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label141), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label141), 5, 0);

  label142 = gtk_label_new (_("Bitrate RX"));
  gtk_widget_ref (label142);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label142", label142,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label142);
  gtk_table_attach (GTK_TABLE (table7), label142, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label142), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label142), 5, 0);

  label147 = gtk_label_new (_("Bitrate TX"));
  gtk_widget_ref (label147);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label147", label147,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label147);
  gtk_table_attach (GTK_TABLE (table7), label147, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label147), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label147), 5, 0);

  mode = gtk_combo_new ();
  gtk_widget_ref (mode);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "mode", mode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mode);
  gtk_table_attach (GTK_TABLE (table7), mode, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 4);
  gtk_combo_set_value_in_list (GTK_COMBO (mode), TRUE, FALSE);
  mode_items = g_list_append (mode_items, _("-"));
  mode_items = g_list_append (mode_items, _("fsk"));
  mode_items = g_list_append (mode_items, _("afsk"));
  mode_items = g_list_append (mode_items, _("audio"));
  mode_items = g_list_append (mode_items, _("external"));
  gtk_combo_set_popdown_strings (GTK_COMBO (mode), mode_items);
  g_list_free (mode_items);

  modeentry = GTK_COMBO (mode)->entry;
  gtk_widget_ref (modeentry);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "modeentry", modeentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (modeentry);
  gtk_entry_set_editable (GTK_ENTRY (modeentry), FALSE);
  gtk_entry_set_text (GTK_ENTRY (modeentry), _("-"));

  bitraterx_adj = gtk_adjustment_new (9600, 1200, 310000, 1200, 9600, 9600);
  bitraterx = gtk_spin_button_new (GTK_ADJUSTMENT (bitraterx_adj), 1, 0);
  gtk_widget_ref (bitraterx);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "bitraterx", bitraterx,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bitraterx);
  gtk_table_attach (GTK_TABLE (table7), bitraterx, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 4);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (bitraterx), TRUE);

  bitratetx_adj = gtk_adjustment_new (9600, 1200, 310000, 1200, 9600, 9600);
  bitratetx = gtk_spin_button_new (GTK_ADJUSTMENT (bitratetx_adj), 1, 0);
  gtk_widget_ref (bitratetx);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "bitratetx", bitratetx,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (bitratetx);
  gtk_table_attach (GTK_TABLE (table7), bitratetx, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 4, 4);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (bitratetx), TRUE);

  label143 = gtk_label_new (_("Bit/s"));
  gtk_widget_ref (label143);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label143", label143,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label143);
  gtk_table_attach (GTK_TABLE (table7), label143, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label143), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label143), 5, 0);

  label146 = gtk_label_new (_("Bit/s"));
  gtk_widget_ref (label146);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "label146", label146,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label146);
  gtk_table_attach (GTK_TABLE (table7), label146, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label146), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label146), 5, 0);

  hbuttonbox6 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox6);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "hbuttonbox6", hbuttonbox6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox6);
  gtk_box_pack_start (GTK_BOX (vbox8), hbuttonbox6, FALSE, TRUE, 5);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox6), GTK_BUTTONBOX_SPREAD);

  buttonok = gtk_button_new_with_label (_("OK"));
  gtk_widget_ref (buttonok);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "buttonok", buttonok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttonok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), buttonok);
  GTK_WIDGET_SET_FLAGS (buttonok, GTK_CAN_DEFAULT);

  buttoncancel = gtk_button_new_with_label (_("Cancel"));
  gtk_widget_ref (buttoncancel);
  gtk_object_set_data_full (GTK_OBJECT (newstationwindow), "buttoncancel", buttoncancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttoncancel);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), buttoncancel);
  GTK_WIDGET_SET_FLAGS (buttoncancel, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (newstationwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_newstationwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (modeentry), "changed",
                      GTK_SIGNAL_FUNC (on_newstnmodeentry_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttonok), "clicked",
                      GTK_SIGNAL_FUNC (on_newstnok_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttoncancel), "clicked",
                      GTK_SIGNAL_FUNC (on_newstncancel_clicked),
                      NULL);

  return newstationwindow;
}

GtkWidget*
create_modemselectwindow (void)
{
  GtkWidget *modemselectwindow;
  GtkWidget *vbox9;
  GtkWidget *scrolledwindow3;
  GtkWidget *modemlist;
  GtkWidget *label134;
  GtkWidget *label135;
  GtkWidget *label136;
  GtkWidget *hbuttonbox7;
  GtkWidget *modemselok;
  GtkWidget *modemselcancel;

  modemselectwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (modemselectwindow), "modemselectwindow", modemselectwindow);
  gtk_window_set_title (GTK_WINDOW (modemselectwindow), _("Modem/Transceiver Selection"));
  gtk_window_set_wmclass (GTK_WINDOW (modemselectwindow), "baycomusb", "baycomusb");

  vbox9 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox9);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "vbox9", vbox9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox9);
  gtk_container_add (GTK_CONTAINER (modemselectwindow), vbox9);

  scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (scrolledwindow3);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "scrolledwindow3", scrolledwindow3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow3);
  gtk_box_pack_start (GTK_BOX (vbox9), scrolledwindow3, TRUE, TRUE, 0);

  modemlist = gtk_clist_new (3);
  gtk_widget_ref (modemlist);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "modemlist", modemlist,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (modemlist);
  gtk_container_add (GTK_CONTAINER (scrolledwindow3), modemlist);
  gtk_clist_set_column_width (GTK_CLIST (modemlist), 0, 141);
  gtk_clist_set_column_width (GTK_CLIST (modemlist), 1, 103);
  gtk_clist_set_column_width (GTK_CLIST (modemlist), 2, 80);
  gtk_clist_column_titles_show (GTK_CLIST (modemlist));

  label134 = gtk_label_new (_("Manufacturer"));
  gtk_widget_ref (label134);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "label134", label134,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label134);
  gtk_clist_set_column_widget (GTK_CLIST (modemlist), 0, label134);

  label135 = gtk_label_new (_("Model"));
  gtk_widget_ref (label135);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "label135", label135,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label135);
  gtk_clist_set_column_widget (GTK_CLIST (modemlist), 1, label135);

  label136 = gtk_label_new (_("Serial Number"));
  gtk_widget_ref (label136);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "label136", label136,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label136);
  gtk_clist_set_column_widget (GTK_CLIST (modemlist), 2, label136);

  hbuttonbox7 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox7);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "hbuttonbox7", hbuttonbox7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox7);
  gtk_box_pack_start (GTK_BOX (vbox9), hbuttonbox7, FALSE, TRUE, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox7), GTK_BUTTONBOX_SPREAD);

  modemselok = gtk_button_new_with_label (_("OK"));
  gtk_widget_ref (modemselok);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "modemselok", modemselok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (modemselok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), modemselok);
  GTK_WIDGET_SET_FLAGS (modemselok, GTK_CAN_DEFAULT);

  modemselcancel = gtk_button_new_with_label (_("Cancel"));
  gtk_widget_ref (modemselcancel);
  gtk_object_set_data_full (GTK_OBJECT (modemselectwindow), "modemselcancel", modemselcancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (modemselcancel);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), modemselcancel);
  GTK_WIDGET_SET_FLAGS (modemselcancel, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (modemselectwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_modemselectwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (modemlist), "select_row",
                      GTK_SIGNAL_FUNC (on_modemlist_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (modemlist), "unselect_row",
                      GTK_SIGNAL_FUNC (on_modemlist_unselect_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (modemselok), "clicked",
                      GTK_SIGNAL_FUNC (on_modemselok_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (modemselcancel), "clicked",
                      GTK_SIGNAL_FUNC (on_modemselcancel_clicked),
                      NULL);

  return modemselectwindow;
}

GtkWidget*
create_configwindow (void)
{
  GtkWidget *configwindow;
  GtkWidget *vbox1;
  GtkWidget *confignotebook;
  GtkWidget *table1;
  GtkWidget *label22;
  GtkWidget *label23;
  GtkWidget *label24;
  GtkWidget *label144;
  GtkWidget *adaptmode;
  GList *adaptmode_items = NULL;
  GtkWidget *adaptmodeentry;
  GtkObject *adaptfclk_adj;
  GtkWidget *adaptfclk;
  GtkWidget *label29;
  GtkObject *adaptbitraterx_adj;
  GtkWidget *adaptbitraterx;
  GtkWidget *label65;
  GtkObject *adaptbitratetx_adj;
  GtkWidget *adaptbitratetx;
  GtkWidget *label145;
  GtkWidget *label25;
  GtkWidget *label26;
  GtkWidget *adaptpttmute;
  GtkWidget *label27;
  GtkWidget *adaptfiltmode;
  GtkWidget *adaptfiltmodeentry;
  GtkWidget *adaptloopback;
  GList *adaptloopback_items = NULL;
  GtkWidget *adaptloopbackentry;
  GtkWidget *label18;
  GtkWidget *table8;
  GtkWidget *label64;
  GtkWidget *label28;
  GtkWidget *label66;
  GtkObject *adaptsamplerate_adj;
  GtkWidget *adaptsamplerate;
  GtkObject *adaptgain_adj;
  GtkWidget *adaptgain;
  GtkWidget *label150;
  GtkWidget *label149;
  GtkWidget *adaptaudiodevin;
  GtkWidget *adaptaudiodevinentry;
  GtkWidget *adaptaudiodevout;
  GtkWidget *adaptaudiodevoutentry;
  GtkWidget *adaptaudiosquelch;
  GtkWidget *adaptrfsquelch;
  GtkWidget *label152;
  GtkWidget *label153;
  GtkWidget *label148;
  GtkWidget *table2;
  GtkWidget *chaccfullduplex;
  GtkWidget *label34;
  GtkWidget *label33;
  GtkWidget *label32;
  GtkWidget *label31;
  GtkWidget *label30;
  GtkWidget *label35;
  GtkWidget *label36;
  GtkWidget *label37;
  GtkObject *chaccppersistence_adj;
  GtkWidget *chaccppersistence;
  GtkObject *chaccslottime_adj;
  GtkWidget *chaccslottime;
  GtkObject *chacctxtail_adj;
  GtkWidget *chacctxtail;
  GtkObject *chacctxdelay_adj;
  GtkWidget *chacctxdelay;
  GtkWidget *label19;
  GtkWidget *table3;
  GtkWidget *ifcfgifname;
  GList *ifcfgifname_items = NULL;
  GtkWidget *ifcfgifnameentry;
  GtkWidget *ifcfghwaddr;
  GtkWidget *ifcfgipaddr;
  GtkWidget *ifcfgnetmask;
  GtkWidget *ifcfgbroadcast;
  GtkWidget *label39;
  GtkWidget *label40;
  GtkWidget *label41;
  GtkWidget *label42;
  GtkWidget *label43;
  GtkWidget *label137;
  GtkWidget *label138;
  GtkWidget *label139;
  GtkWidget *label140;
  GtkWidget *ifcfggwhwaddr;
  GtkWidget *ifcfggwipaddr;
  GtkWidget *ifcfggwnetmask;
  GtkWidget *ifcfggwipmode;
  GList *ifcfggwipmode_items = NULL;
  GtkWidget *ifcfggwipmodeentry;
  GtkWidget *label20;
  GtkWidget *table5;
  GtkWidget *label53;
  GtkWidget *label52;
  GtkWidget *label51;
  GtkWidget *label50;
  GtkWidget *label49;
  GtkWidget *label48;
  GtkWidget *label47;
  GtkWidget *label46;
  GSList *mdisc4_group = NULL;
  GtkWidget *mdisc4l;
  GSList *mdisc5_group = NULL;
  GtkWidget *mdisc5l;
  GSList *mdisc6_group = NULL;
  GtkWidget *mdisc6l;
  GSList *mdisc7_group = NULL;
  GtkWidget *mdisc7l;
  GSList *mdisc3_group = NULL;
  GtkWidget *mdisc3l;
  GSList *mdisc1_group = NULL;
  GtkWidget *mdisc1l;
  GSList *mdisc2_group = NULL;
  GtkWidget *mdisc2l;
  GSList *mdisc0_group = NULL;
  GtkWidget *mdisc0l;
  GtkWidget *mdisc0h;
  GtkWidget *mdisc2h;
  GtkWidget *mdisc1h;
  GtkWidget *mdisc3h;
  GtkWidget *mdisc4h;
  GtkWidget *mdisc5h;
  GtkWidget *mdisc6h;
  GtkWidget *mdisc7h;
  GtkWidget *mdisc0t;
  GtkWidget *mdisc2t;
  GtkWidget *mdisc1t;
  GtkWidget *mdisc3t;
  GtkWidget *mdisc4t;
  GtkWidget *mdisc5t;
  GtkWidget *mdisc6t;
  GtkWidget *mdisc7t;
  GtkWidget *label55;
  GtkWidget *label54;
  GtkWidget *label56;
  GtkWidget *label57;
  GtkWidget *label58;
  GtkWidget *label59;
  GtkWidget *label60;
  GtkWidget *label61;
  GtkWidget *mdisctxd;
  GList *mdisctxd_items = NULL;
  GtkWidget *mdisctxdentry;
  GtkWidget *mdiscrxc;
  GList *mdiscrxc_items = NULL;
  GtkWidget *mdiscrxcentry;
  GtkWidget *mdisctxc;
  GList *mdisctxc_items = NULL;
  GtkWidget *mdisctxcentry;
  GtkWidget *label21;
  GtkWidget *hbuttonbox8;
  GtkWidget *configok;
  GtkWidget *configcancel;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  configwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (configwindow), "configwindow", configwindow);
  gtk_window_set_title (GTK_WINDOW (configwindow), _("Baycom USB Adapter Configuration"));
  gtk_window_set_wmclass (GTK_WINDOW (configwindow), "baycomusb", "baycomusb");

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox1);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "vbox1", vbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (configwindow), vbox1);

  confignotebook = gtk_notebook_new ();
  gtk_widget_ref (confignotebook);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "confignotebook", confignotebook,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (confignotebook);
  gtk_box_pack_start (GTK_BOX (vbox1), confignotebook, TRUE, TRUE, 0);

  table1 = gtk_table_new (7, 3, FALSE);
  gtk_widget_ref (table1);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "table1", table1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (confignotebook), table1);

  label22 = gtk_label_new (_("Mode"));
  gtk_widget_ref (label22);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label22", label22,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label22);
  gtk_table_attach (GTK_TABLE (table1), label22, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label22), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label22), 5, 0);

  label23 = gtk_label_new (_("FPGA clock"));
  gtk_widget_ref (label23);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label23", label23,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label23);
  gtk_table_attach (GTK_TABLE (table1), label23, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label23), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label23), 5, 0);

  label24 = gtk_label_new (_("Bitrate RX"));
  gtk_widget_ref (label24);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label24", label24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label24);
  gtk_table_attach (GTK_TABLE (table1), label24, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label24), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label24), 5, 0);

  label144 = gtk_label_new (_("Bitrate TX"));
  gtk_widget_ref (label144);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label144", label144,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label144);
  gtk_table_attach (GTK_TABLE (table1), label144, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label144), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label144), 5, 0);

  adaptmode = gtk_combo_new ();
  gtk_widget_ref (adaptmode);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptmode", adaptmode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptmode);
  gtk_table_attach (GTK_TABLE (table1), adaptmode, 1, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_combo_set_value_in_list (GTK_COMBO (adaptmode), TRUE, FALSE);
  gtk_combo_set_case_sensitive (GTK_COMBO (adaptmode), TRUE);
  adaptmode_items = g_list_append (adaptmode_items, _("fsk"));
  adaptmode_items = g_list_append (adaptmode_items, _("afsk"));
  adaptmode_items = g_list_append (adaptmode_items, _("external"));
  adaptmode_items = g_list_append (adaptmode_items, _("audio"));
  gtk_combo_set_popdown_strings (GTK_COMBO (adaptmode), adaptmode_items);
  g_list_free (adaptmode_items);

  adaptmodeentry = GTK_COMBO (adaptmode)->entry;
  gtk_widget_ref (adaptmodeentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptmodeentry", adaptmodeentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptmodeentry);
  gtk_entry_set_text (GTK_ENTRY (adaptmodeentry), _("fsk"));

  adaptfclk_adj = gtk_adjustment_new (1.96666e+07, 1e+06, 2.5e+07, 1, 10, 10);
  adaptfclk = gtk_spin_button_new (GTK_ADJUSTMENT (adaptfclk_adj), 1, 0);
  gtk_widget_ref (adaptfclk);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptfclk", adaptfclk,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptfclk);
  gtk_table_attach (GTK_TABLE (table1), adaptfclk, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  label29 = gtk_label_new (_("Hz"));
  gtk_widget_ref (label29);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label29", label29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label29);
  gtk_table_attach (GTK_TABLE (table1), label29, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label29), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label29), 5, 0);

  adaptbitraterx_adj = gtk_adjustment_new (9600, 10, 310000, 1200, 9600, 9600);
  adaptbitraterx = gtk_spin_button_new (GTK_ADJUSTMENT (adaptbitraterx_adj), 1, 0);
  gtk_widget_ref (adaptbitraterx);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptbitraterx", adaptbitraterx,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptbitraterx);
  gtk_table_attach (GTK_TABLE (table1), adaptbitraterx, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_tooltips_set_tip (tooltips, adaptbitraterx, _("used only in FSK and EXTERNAL mode"), NULL);

  label65 = gtk_label_new (_("Bits/s"));
  gtk_widget_ref (label65);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label65", label65,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label65);
  gtk_table_attach (GTK_TABLE (table1), label65, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label65), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label65), 5, 0);

  adaptbitratetx_adj = gtk_adjustment_new (9600, 10, 310000, 1200, 9600, 9600);
  adaptbitratetx = gtk_spin_button_new (GTK_ADJUSTMENT (adaptbitratetx_adj), 1, 0);
  gtk_widget_ref (adaptbitratetx);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptbitratetx", adaptbitratetx,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptbitratetx);
  gtk_table_attach (GTK_TABLE (table1), adaptbitratetx, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_tooltips_set_tip (tooltips, adaptbitratetx, _("used only in FSK and EXTERNAL mode"), NULL);

  label145 = gtk_label_new (_("Bits/s"));
  gtk_widget_ref (label145);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label145", label145,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label145);
  gtk_table_attach (GTK_TABLE (table1), label145, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label145), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label145), 5, 0);

  label25 = gtk_label_new (_("Loopback"));
  gtk_widget_ref (label25);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label25", label25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label25);
  gtk_table_attach (GTK_TABLE (table1), label25, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label25), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label25), 5, 0);

  label26 = gtk_label_new (_("PTT Mute"));
  gtk_widget_ref (label26);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label26", label26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label26);
  gtk_table_attach (GTK_TABLE (table1), label26, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label26), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label26), 5, 0);

  adaptpttmute = gtk_check_button_new_with_label ("");
  gtk_widget_ref (adaptpttmute);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptpttmute", adaptpttmute,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptpttmute);
  gtk_table_attach (GTK_TABLE (table1), adaptpttmute, 1, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label27 = gtk_label_new (_("Filter Mode"));
  gtk_widget_ref (label27);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label27", label27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label27);
  gtk_table_attach (GTK_TABLE (table1), label27, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label27), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label27), 5, 0);

  adaptfiltmode = gtk_combo_new ();
  gtk_widget_ref (adaptfiltmode);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptfiltmode", adaptfiltmode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptfiltmode);
  gtk_table_attach (GTK_TABLE (table1), adaptfiltmode, 1, 3, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_combo_set_value_in_list (GTK_COMBO (adaptfiltmode), TRUE, FALSE);
  gtk_combo_set_case_sensitive (GTK_COMBO (adaptfiltmode), TRUE);

  adaptfiltmodeentry = GTK_COMBO (adaptfiltmode)->entry;
  gtk_widget_ref (adaptfiltmodeentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptfiltmodeentry", adaptfiltmodeentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptfiltmodeentry);
  gtk_entry_set_text (GTK_ENTRY (adaptfiltmodeentry), _("0"));

  adaptloopback = gtk_combo_new ();
  gtk_widget_ref (adaptloopback);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptloopback", adaptloopback,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptloopback);
  gtk_table_attach (GTK_TABLE (table1), adaptloopback, 1, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_combo_set_value_in_list (GTK_COMBO (adaptloopback), TRUE, FALSE);
  gtk_combo_set_case_sensitive (GTK_COMBO (adaptloopback), TRUE);
  adaptloopback_items = g_list_append (adaptloopback_items, _("0"));
  gtk_combo_set_popdown_strings (GTK_COMBO (adaptloopback), adaptloopback_items);
  g_list_free (adaptloopback_items);

  adaptloopbackentry = GTK_COMBO (adaptloopback)->entry;
  gtk_widget_ref (adaptloopbackentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptloopbackentry", adaptloopbackentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptloopbackentry);
  gtk_entry_set_text (GTK_ENTRY (adaptloopbackentry), _("0"));

  label18 = gtk_label_new (_("Adapter"));
  gtk_widget_ref (label18);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label18", label18,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label18);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (confignotebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (confignotebook), 0), label18);

  table8 = gtk_table_new (6, 3, FALSE);
  gtk_widget_ref (table8);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "table8", table8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table8);
  gtk_container_add (GTK_CONTAINER (confignotebook), table8);

  label64 = gtk_label_new (_("Sample Rate"));
  gtk_widget_ref (label64);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label64", label64,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label64);
  gtk_table_attach (GTK_TABLE (table8), label64, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label64), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label64), 5, 0);

  label28 = gtk_label_new (_("Gain"));
  gtk_widget_ref (label28);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label28", label28,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label28);
  gtk_table_attach (GTK_TABLE (table8), label28, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label28), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label28), 5, 0);

  label66 = gtk_label_new (_("Samples/s"));
  gtk_widget_ref (label66);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label66", label66,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label66);
  gtk_table_attach (GTK_TABLE (table8), label66, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label66), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label66), 5, 0);

  adaptsamplerate_adj = gtk_adjustment_new (8000, 8000, 24000, 1000, 8000, 8000);
  adaptsamplerate = gtk_spin_button_new (GTK_ADJUSTMENT (adaptsamplerate_adj), 1, 0);
  gtk_widget_ref (adaptsamplerate);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptsamplerate", adaptsamplerate,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptsamplerate);
  gtk_table_attach (GTK_TABLE (table8), adaptsamplerate, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_tooltips_set_tip (tooltips, adaptsamplerate, _("used only in AUDIO mode"), NULL);

  adaptgain_adj = gtk_adjustment_new (1, 0, 100, 0.1, 1, 10);
  adaptgain = gtk_spin_button_new (GTK_ADJUSTMENT (adaptgain_adj), 1, 3);
  gtk_widget_ref (adaptgain);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptgain", adaptgain,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptgain);
  gtk_table_attach (GTK_TABLE (table8), adaptgain, 1, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  label150 = gtk_label_new (_("Speaker Audio Device"));
  gtk_widget_ref (label150);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label150", label150,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label150);
  gtk_table_attach (GTK_TABLE (table8), label150, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label150), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label150), 5, 0);

  label149 = gtk_label_new (_("Microphone Audio Device"));
  gtk_widget_ref (label149);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label149", label149,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label149);
  gtk_table_attach (GTK_TABLE (table8), label149, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label149), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label149), 5, 0);

  adaptaudiodevin = gtk_combo_new ();
  gtk_widget_ref (adaptaudiodevin);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptaudiodevin", adaptaudiodevin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptaudiodevin);
  gtk_table_attach (GTK_TABLE (table8), adaptaudiodevin, 1, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_combo_set_case_sensitive (GTK_COMBO (adaptaudiodevin), TRUE);

  adaptaudiodevinentry = GTK_COMBO (adaptaudiodevin)->entry;
  gtk_widget_ref (adaptaudiodevinentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptaudiodevinentry", adaptaudiodevinentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptaudiodevinentry);
  gtk_entry_set_text (GTK_ENTRY (adaptaudiodevinentry), _("/dev/dsp"));

  adaptaudiodevout = gtk_combo_new ();
  gtk_widget_ref (adaptaudiodevout);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptaudiodevout", adaptaudiodevout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptaudiodevout);
  gtk_table_attach (GTK_TABLE (table8), adaptaudiodevout, 1, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_combo_set_case_sensitive (GTK_COMBO (adaptaudiodevout), TRUE);

  adaptaudiodevoutentry = GTK_COMBO (adaptaudiodevout)->entry;
  gtk_widget_ref (adaptaudiodevoutentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptaudiodevoutentry", adaptaudiodevoutentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptaudiodevoutentry);
  gtk_entry_set_text (GTK_ENTRY (adaptaudiodevoutentry), _("/dev/dsp"));

  adaptaudiosquelch = gtk_check_button_new_with_label ("");
  gtk_widget_ref (adaptaudiosquelch);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptaudiosquelch", adaptaudiosquelch,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptaudiosquelch);
  gtk_table_attach (GTK_TABLE (table8), adaptaudiosquelch, 1, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  adaptrfsquelch = gtk_hscale_new (GTK_ADJUSTMENT (gtk_adjustment_new (-120, -120, -35, 0, 0, 0)));
  gtk_widget_ref (adaptrfsquelch);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "adaptrfsquelch", adaptrfsquelch,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (adaptrfsquelch);
  gtk_table_attach (GTK_TABLE (table8), adaptrfsquelch, 1, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_widget_set_usize (adaptrfsquelch, 150, -2);

  label152 = gtk_label_new (_("RF Squelch Level"));
  gtk_widget_ref (label152);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label152", label152,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label152);
  gtk_table_attach (GTK_TABLE (table8), label152, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label152), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label152), 5, 0);

  label153 = gtk_label_new (_("Audio Squelch"));
  gtk_widget_ref (label153);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label153", label153,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label153);
  gtk_table_attach (GTK_TABLE (table8), label153, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label153), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label153), 5, 0);

  label148 = gtk_label_new (_("Audio"));
  gtk_widget_ref (label148);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label148", label148,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label148);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (confignotebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (confignotebook), 1), label148);

  table2 = gtk_table_new (5, 3, FALSE);
  gtk_widget_ref (table2);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "table2", table2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table2);
  gtk_container_add (GTK_CONTAINER (confignotebook), table2);

  chaccfullduplex = gtk_check_button_new_with_label ("");
  gtk_widget_ref (chaccfullduplex);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "chaccfullduplex", chaccfullduplex,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chaccfullduplex);
  gtk_table_attach (GTK_TABLE (table2), chaccfullduplex, 1, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 3, 3);

  label34 = gtk_label_new (_("Full Duplex"));
  gtk_widget_ref (label34);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label34", label34,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label34);
  gtk_table_attach (GTK_TABLE (table2), label34, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label34), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label34), 5, 0);

  label33 = gtk_label_new (_("P-Persistence"));
  gtk_widget_ref (label33);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label33", label33,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label33);
  gtk_table_attach (GTK_TABLE (table2), label33, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label33), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label33), 5, 0);

  label32 = gtk_label_new (_("SlotTime"));
  gtk_widget_ref (label32);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label32", label32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label32);
  gtk_table_attach (GTK_TABLE (table2), label32, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label32), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label32), 5, 0);

  label31 = gtk_label_new (_("TxTail"));
  gtk_widget_ref (label31);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label31", label31,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label31);
  gtk_table_attach (GTK_TABLE (table2), label31, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label31), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label31), 5, 0);

  label30 = gtk_label_new (_("TxDelay"));
  gtk_widget_ref (label30);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label30", label30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label30);
  gtk_table_attach (GTK_TABLE (table2), label30, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label30), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label30), 5, 0);

  label35 = gtk_label_new (_("ms"));
  gtk_widget_ref (label35);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label35", label35,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label35);
  gtk_table_attach (GTK_TABLE (table2), label35, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label35), 5, 0);

  label36 = gtk_label_new (_("ms"));
  gtk_widget_ref (label36);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label36", label36,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label36);
  gtk_table_attach (GTK_TABLE (table2), label36, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label36), 5, 0);

  label37 = gtk_label_new (_("ms"));
  gtk_widget_ref (label37);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label37", label37,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label37);
  gtk_table_attach (GTK_TABLE (table2), label37, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label37), 5, 0);

  chaccppersistence_adj = gtk_adjustment_new (40, 0, 255, 1, 10, 10);
  chaccppersistence = gtk_spin_button_new (GTK_ADJUSTMENT (chaccppersistence_adj), 1, 0);
  gtk_widget_ref (chaccppersistence);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "chaccppersistence", chaccppersistence,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chaccppersistence);
  gtk_table_attach (GTK_TABLE (table2), chaccppersistence, 1, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  chaccslottime_adj = gtk_adjustment_new (100, 0, 2550, 10, 100, 100);
  chaccslottime = gtk_spin_button_new (GTK_ADJUSTMENT (chaccslottime_adj), 1, 0);
  gtk_widget_ref (chaccslottime);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "chaccslottime", chaccslottime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chaccslottime);
  gtk_table_attach (GTK_TABLE (table2), chaccslottime, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  chacctxtail_adj = gtk_adjustment_new (30, 0, 2550, 10, 100, 100);
  chacctxtail = gtk_spin_button_new (GTK_ADJUSTMENT (chacctxtail_adj), 1, 0);
  gtk_widget_ref (chacctxtail);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "chacctxtail", chacctxtail,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chacctxtail);
  gtk_table_attach (GTK_TABLE (table2), chacctxtail, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  chacctxdelay_adj = gtk_adjustment_new (150, 0, 2550, 10, 100, 100);
  chacctxdelay = gtk_spin_button_new (GTK_ADJUSTMENT (chacctxdelay_adj), 1, 0);
  gtk_widget_ref (chacctxdelay);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "chacctxdelay", chacctxdelay,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chacctxdelay);
  gtk_table_attach (GTK_TABLE (table2), chacctxdelay, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  label19 = gtk_label_new (_("Channel Access"));
  gtk_widget_ref (label19);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label19", label19,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label19);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (confignotebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (confignotebook), 2), label19);

  table3 = gtk_table_new (9, 3, FALSE);
  gtk_widget_ref (table3);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "table3", table3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table3);
  gtk_container_add (GTK_CONTAINER (confignotebook), table3);

  ifcfgifname = gtk_combo_new ();
  gtk_widget_ref (ifcfgifname);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfgifname", ifcfgifname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfgifname);
  gtk_table_attach (GTK_TABLE (table3), ifcfgifname, 1, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  ifcfgifname_items = g_list_append (ifcfgifname_items, _("bcu0"));
  ifcfgifname_items = g_list_append (ifcfgifname_items, _("bcu1"));
  ifcfgifname_items = g_list_append (ifcfgifname_items, _("bcu2"));
  ifcfgifname_items = g_list_append (ifcfgifname_items, _("bcu3"));
  gtk_combo_set_popdown_strings (GTK_COMBO (ifcfgifname), ifcfgifname_items);
  g_list_free (ifcfgifname_items);

  ifcfgifnameentry = GTK_COMBO (ifcfgifname)->entry;
  gtk_widget_ref (ifcfgifnameentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfgifnameentry", ifcfgifnameentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfgifnameentry);
  gtk_entry_set_text (GTK_ENTRY (ifcfgifnameentry), _("bcu0"));

  ifcfghwaddr = gtk_entry_new_with_max_length (9);
  gtk_widget_ref (ifcfghwaddr);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfghwaddr", ifcfghwaddr,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfghwaddr);
  gtk_table_attach (GTK_TABLE (table3), ifcfghwaddr, 1, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  ifcfgipaddr = gtk_entry_new_with_max_length (15);
  gtk_widget_ref (ifcfgipaddr);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfgipaddr", ifcfgipaddr,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfgipaddr);
  gtk_table_attach (GTK_TABLE (table3), ifcfgipaddr, 1, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_entry_set_text (GTK_ENTRY (ifcfgipaddr), _("10.0.0.1"));

  ifcfgnetmask = gtk_entry_new_with_max_length (15);
  gtk_widget_ref (ifcfgnetmask);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfgnetmask", ifcfgnetmask,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfgnetmask);
  gtk_table_attach (GTK_TABLE (table3), ifcfgnetmask, 1, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_entry_set_text (GTK_ENTRY (ifcfgnetmask), _("255.255.255.0"));

  ifcfgbroadcast = gtk_entry_new_with_max_length (15);
  gtk_widget_ref (ifcfgbroadcast);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfgbroadcast", ifcfgbroadcast,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfgbroadcast);
  gtk_table_attach (GTK_TABLE (table3), ifcfgbroadcast, 1, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_entry_set_text (GTK_ENTRY (ifcfgbroadcast), _("10.0.0.255"));

  label39 = gtk_label_new (_("Interface Name"));
  gtk_widget_ref (label39);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label39", label39,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label39);
  gtk_table_attach (GTK_TABLE (table3), label39, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label39), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label39), 5, 0);

  label40 = gtk_label_new (_("Callsign"));
  gtk_widget_ref (label40);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label40", label40,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label40);
  gtk_table_attach (GTK_TABLE (table3), label40, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label40), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label40), 5, 0);

  label41 = gtk_label_new (_("IP Address"));
  gtk_widget_ref (label41);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label41", label41,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label41);
  gtk_table_attach (GTK_TABLE (table3), label41, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label41), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label41), 5, 0);

  label42 = gtk_label_new (_("Netmask"));
  gtk_widget_ref (label42);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label42", label42,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label42);
  gtk_table_attach (GTK_TABLE (table3), label42, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label42), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label42), 5, 0);

  label43 = gtk_label_new (_("IP Broadcast Address"));
  gtk_widget_ref (label43);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label43", label43,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label43);
  gtk_table_attach (GTK_TABLE (table3), label43, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label43), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label43), 5, 0);

  label137 = gtk_label_new (_("Gateway AX.25 Path"));
  gtk_widget_ref (label137);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label137", label137,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label137);
  gtk_table_attach (GTK_TABLE (table3), label137, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label137), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label137), 5, 0);

  label138 = gtk_label_new (_("Gateway IP Address"));
  gtk_widget_ref (label138);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label138", label138,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label138);
  gtk_table_attach (GTK_TABLE (table3), label138, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label138), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label138), 5, 0);

  label139 = gtk_label_new (_("Gateway Genmask"));
  gtk_widget_ref (label139);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label139", label139,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label139);
  gtk_table_attach (GTK_TABLE (table3), label139, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label139), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label139), 5, 0);

  label140 = gtk_label_new (_("Gateway IP Mode"));
  gtk_widget_ref (label140);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label140", label140,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label140);
  gtk_table_attach (GTK_TABLE (table3), label140, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label140), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label140), 5, 0);

  ifcfggwhwaddr = gtk_entry_new_with_max_length (80);
  gtk_widget_ref (ifcfggwhwaddr);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfggwhwaddr", ifcfggwhwaddr,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfggwhwaddr);
  gtk_table_attach (GTK_TABLE (table3), ifcfggwhwaddr, 1, 3, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  ifcfggwipaddr = gtk_entry_new_with_max_length (15);
  gtk_widget_ref (ifcfggwipaddr);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfggwipaddr", ifcfggwipaddr,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfggwipaddr);
  gtk_table_attach (GTK_TABLE (table3), ifcfggwipaddr, 1, 3, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  ifcfggwnetmask = gtk_entry_new_with_max_length (15);
  gtk_widget_ref (ifcfggwnetmask);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfggwnetmask", ifcfggwnetmask,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfggwnetmask);
  gtk_table_attach (GTK_TABLE (table3), ifcfggwnetmask, 1, 3, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);

  ifcfggwipmode = gtk_combo_new ();
  gtk_widget_ref (ifcfggwipmode);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfggwipmode", ifcfggwipmode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfggwipmode);
  gtk_table_attach (GTK_TABLE (table3), ifcfggwipmode, 1, 3, 8, 9,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 3, 3);
  gtk_combo_set_value_in_list (GTK_COMBO (ifcfggwipmode), TRUE, FALSE);
  ifcfggwipmode_items = g_list_append (ifcfggwipmode_items, _("Default"));
  ifcfggwipmode_items = g_list_append (ifcfggwipmode_items, _("Virtual Circuit"));
  ifcfggwipmode_items = g_list_append (ifcfggwipmode_items, _("Datagram"));
  ifcfggwipmode_items = g_list_append (ifcfggwipmode_items, _("Compressed"));
  gtk_combo_set_popdown_strings (GTK_COMBO (ifcfggwipmode), ifcfggwipmode_items);
  g_list_free (ifcfggwipmode_items);

  ifcfggwipmodeentry = GTK_COMBO (ifcfggwipmode)->entry;
  gtk_widget_ref (ifcfggwipmodeentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "ifcfggwipmodeentry", ifcfggwipmodeentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ifcfggwipmodeentry);
  gtk_entry_set_text (GTK_ENTRY (ifcfggwipmodeentry), _("Default"));

  label20 = gtk_label_new (_("Interface"));
  gtk_widget_ref (label20);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label20", label20,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label20);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (confignotebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (confignotebook), 3), label20);

  table5 = gtk_table_new (8, 6, FALSE);
  gtk_widget_ref (table5);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "table5", table5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table5);
  gtk_container_add (GTK_CONTAINER (confignotebook), table5);

  label53 = gtk_label_new (_("Pin 5"));
  gtk_widget_ref (label53);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label53", label53,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label53);
  gtk_table_attach (GTK_TABLE (table5), label53, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label53), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label53), 5, 0);

  label52 = gtk_label_new (_("Pin 7"));
  gtk_widget_ref (label52);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label52", label52,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label52);
  gtk_table_attach (GTK_TABLE (table5), label52, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label52), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label52), 5, 0);

  label51 = gtk_label_new (_("Pin 9"));
  gtk_widget_ref (label51);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label51", label51,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label51);
  gtk_table_attach (GTK_TABLE (table5), label51, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label51), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label51), 5, 0);

  label50 = gtk_label_new (_("Pin 11"));
  gtk_widget_ref (label50);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label50", label50,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label50);
  gtk_table_attach (GTK_TABLE (table5), label50, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label50), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label50), 5, 0);

  label49 = gtk_label_new (_("Pin 13"));
  gtk_widget_ref (label49);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label49", label49,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label49);
  gtk_table_attach (GTK_TABLE (table5), label49, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label49), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label49), 5, 0);

  label48 = gtk_label_new (_("Pin 15"));
  gtk_widget_ref (label48);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label48", label48,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label48);
  gtk_table_attach (GTK_TABLE (table5), label48, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label48), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label48), 5, 0);

  label47 = gtk_label_new (_("Pin 17"));
  gtk_widget_ref (label47);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label47", label47,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label47);
  gtk_table_attach (GTK_TABLE (table5), label47, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label47), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label47), 5, 0);

  label46 = gtk_label_new (_("Pin 19"));
  gtk_widget_ref (label46);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label46", label46,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label46);
  gtk_table_attach (GTK_TABLE (table5), label46, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label46), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label46), 5, 0);

  mdisc4l = gtk_radio_button_new_with_label (mdisc4_group, _("0"));
  mdisc4_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc4l));
  gtk_widget_ref (mdisc4l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc4l", mdisc4l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc4l);
  gtk_table_attach (GTK_TABLE (table5), mdisc4l, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc5l = gtk_radio_button_new_with_label (mdisc5_group, _("0"));
  mdisc5_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc5l));
  gtk_widget_ref (mdisc5l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc5l", mdisc5l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc5l);
  gtk_table_attach (GTK_TABLE (table5), mdisc5l, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc6l = gtk_radio_button_new_with_label (mdisc6_group, _("0"));
  mdisc6_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc6l));
  gtk_widget_ref (mdisc6l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc6l", mdisc6l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc6l);
  gtk_table_attach (GTK_TABLE (table5), mdisc6l, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc7l = gtk_radio_button_new_with_label (mdisc7_group, _("0"));
  mdisc7_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc7l));
  gtk_widget_ref (mdisc7l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc7l", mdisc7l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc7l);
  gtk_table_attach (GTK_TABLE (table5), mdisc7l, 2, 3, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc3l = gtk_radio_button_new_with_label (mdisc3_group, _("0"));
  mdisc3_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc3l));
  gtk_widget_ref (mdisc3l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc3l", mdisc3l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc3l);
  gtk_table_attach (GTK_TABLE (table5), mdisc3l, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc1l = gtk_radio_button_new_with_label (mdisc1_group, _("0"));
  mdisc1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc1l));
  gtk_widget_ref (mdisc1l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc1l", mdisc1l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc1l);
  gtk_table_attach (GTK_TABLE (table5), mdisc1l, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc2l = gtk_radio_button_new_with_label (mdisc2_group, _("0"));
  mdisc2_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc2l));
  gtk_widget_ref (mdisc2l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc2l", mdisc2l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc2l);
  gtk_table_attach (GTK_TABLE (table5), mdisc2l, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc0l = gtk_radio_button_new_with_label (mdisc0_group, _("0"));
  mdisc0_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc0l));
  gtk_widget_ref (mdisc0l);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc0l", mdisc0l,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc0l);
  gtk_table_attach (GTK_TABLE (table5), mdisc0l, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc0h = gtk_radio_button_new_with_label (mdisc0_group, _("1"));
  mdisc0_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc0h));
  gtk_widget_ref (mdisc0h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc0h", mdisc0h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc0h);
  gtk_table_attach (GTK_TABLE (table5), mdisc0h, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc2h = gtk_radio_button_new_with_label (mdisc2_group, _("1"));
  mdisc2_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc2h));
  gtk_widget_ref (mdisc2h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc2h", mdisc2h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc2h);
  gtk_table_attach (GTK_TABLE (table5), mdisc2h, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc1h = gtk_radio_button_new_with_label (mdisc1_group, _("1"));
  mdisc1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc1h));
  gtk_widget_ref (mdisc1h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc1h", mdisc1h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc1h);
  gtk_table_attach (GTK_TABLE (table5), mdisc1h, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc3h = gtk_radio_button_new_with_label (mdisc3_group, _("1"));
  mdisc3_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc3h));
  gtk_widget_ref (mdisc3h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc3h", mdisc3h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc3h);
  gtk_table_attach (GTK_TABLE (table5), mdisc3h, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc4h = gtk_radio_button_new_with_label (mdisc4_group, _("1"));
  mdisc4_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc4h));
  gtk_widget_ref (mdisc4h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc4h", mdisc4h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc4h);
  gtk_table_attach (GTK_TABLE (table5), mdisc4h, 3, 4, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc5h = gtk_radio_button_new_with_label (mdisc5_group, _("1"));
  mdisc5_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc5h));
  gtk_widget_ref (mdisc5h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc5h", mdisc5h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc5h);
  gtk_table_attach (GTK_TABLE (table5), mdisc5h, 3, 4, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc6h = gtk_radio_button_new_with_label (mdisc6_group, _("1"));
  mdisc6_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc6h));
  gtk_widget_ref (mdisc6h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc6h", mdisc6h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc6h);
  gtk_table_attach (GTK_TABLE (table5), mdisc6h, 3, 4, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc7h = gtk_radio_button_new_with_label (mdisc7_group, _("1"));
  mdisc7_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc7h));
  gtk_widget_ref (mdisc7h);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc7h", mdisc7h,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc7h);
  gtk_table_attach (GTK_TABLE (table5), mdisc7h, 3, 4, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);

  mdisc0t = gtk_radio_button_new_with_label (mdisc0_group, _("Input"));
  mdisc0_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc0t));
  gtk_widget_ref (mdisc0t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc0t", mdisc0t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc0t);
  gtk_table_attach (GTK_TABLE (table5), mdisc0t, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc0t), TRUE);

  mdisc2t = gtk_radio_button_new_with_label (mdisc2_group, _("Input"));
  mdisc2_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc2t));
  gtk_widget_ref (mdisc2t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc2t", mdisc2t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc2t);
  gtk_table_attach (GTK_TABLE (table5), mdisc2t, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc2t), TRUE);

  mdisc1t = gtk_radio_button_new_with_label (mdisc1_group, _("Input"));
  mdisc1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc1t));
  gtk_widget_ref (mdisc1t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc1t", mdisc1t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc1t);
  gtk_table_attach (GTK_TABLE (table5), mdisc1t, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc1t), TRUE);

  mdisc3t = gtk_radio_button_new_with_label (mdisc3_group, _("Input"));
  mdisc3_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc3t));
  gtk_widget_ref (mdisc3t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc3t", mdisc3t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc3t);
  gtk_table_attach (GTK_TABLE (table5), mdisc3t, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc3t), TRUE);

  mdisc4t = gtk_radio_button_new_with_label (mdisc4_group, _("Input"));
  mdisc4_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc4t));
  gtk_widget_ref (mdisc4t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc4t", mdisc4t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc4t);
  gtk_table_attach (GTK_TABLE (table5), mdisc4t, 4, 5, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc4t), TRUE);

  mdisc5t = gtk_radio_button_new_with_label (mdisc5_group, _("Input"));
  mdisc5_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc5t));
  gtk_widget_ref (mdisc5t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc5t", mdisc5t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc5t);
  gtk_table_attach (GTK_TABLE (table5), mdisc5t, 4, 5, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc5t), TRUE);

  mdisc6t = gtk_radio_button_new_with_label (mdisc6_group, _("Input"));
  mdisc6_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc6t));
  gtk_widget_ref (mdisc6t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc6t", mdisc6t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc6t);
  gtk_table_attach (GTK_TABLE (table5), mdisc6t, 4, 5, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc6t), TRUE);

  mdisc7t = gtk_radio_button_new_with_label (mdisc7_group, _("Input"));
  mdisc7_group = gtk_radio_button_group (GTK_RADIO_BUTTON (mdisc7t));
  gtk_widget_ref (mdisc7t);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisc7t", mdisc7t,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisc7t);
  gtk_table_attach (GTK_TABLE (table5), mdisc7t, 4, 5, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (mdisc7t), TRUE);

  label55 = gtk_label_new (_("RXC"));
  gtk_widget_ref (label55);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label55", label55,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label55);
  gtk_table_attach (GTK_TABLE (table5), label55, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label55), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label55), 5, 0);

  label54 = gtk_label_new (_("TXC"));
  gtk_widget_ref (label54);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label54", label54,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label54);
  gtk_table_attach (GTK_TABLE (table5), label54, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label54), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label54), 5, 0);

  label56 = gtk_label_new (_("RXD"));
  gtk_widget_ref (label56);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label56", label56,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label56);
  gtk_table_attach (GTK_TABLE (table5), label56, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label56), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label56), 5, 0);

  label57 = gtk_label_new (_("TXD"));
  gtk_widget_ref (label57);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label57", label57,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label57);
  gtk_table_attach (GTK_TABLE (table5), label57, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label57), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label57), 5, 0);

  label58 = gtk_label_new (_("/RTS"));
  gtk_widget_ref (label58);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label58", label58,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label58);
  gtk_table_attach (GTK_TABLE (table5), label58, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label58), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label58), 5, 0);

  label59 = gtk_label_new (_("/CTS"));
  gtk_widget_ref (label59);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label59", label59,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label59);
  gtk_table_attach (GTK_TABLE (table5), label59, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label59), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label59), 5, 0);

  label60 = gtk_label_new (_("/DCD"));
  gtk_widget_ref (label60);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label60", label60,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label60);
  gtk_table_attach (GTK_TABLE (table5), label60, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label60), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label60), 5, 0);

  label61 = gtk_label_new (_("/RES"));
  gtk_widget_ref (label61);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label61", label61,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label61);
  gtk_table_attach (GTK_TABLE (table5), label61, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label61), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label61), 5, 0);

  mdisctxd = gtk_combo_new ();
  gtk_widget_ref (mdisctxd);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisctxd", mdisctxd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisctxd);
  gtk_table_attach (GTK_TABLE (table5), mdisctxd, 5, 6, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_combo_set_value_in_list (GTK_COMBO (mdisctxd), TRUE, FALSE);
  gtk_combo_set_case_sensitive (GTK_COMBO (mdisctxd), TRUE);
  mdisctxd_items = g_list_append (mdisctxd_items, _("Normal"));
  mdisctxd_items = g_list_append (mdisctxd_items, _("TxData"));
  gtk_combo_set_popdown_strings (GTK_COMBO (mdisctxd), mdisctxd_items);
  g_list_free (mdisctxd_items);

  mdisctxdentry = GTK_COMBO (mdisctxd)->entry;
  gtk_widget_ref (mdisctxdentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisctxdentry", mdisctxdentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisctxdentry);
  gtk_widget_set_usize (mdisctxdentry, 60, -2);
  gtk_tooltips_set_tip (tooltips, mdisctxdentry, _("selects the output signal if the internal FSK mode is used"), NULL);
  gtk_entry_set_text (GTK_ENTRY (mdisctxdentry), _("Normal"));

  mdiscrxc = gtk_combo_new ();
  gtk_widget_ref (mdiscrxc);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdiscrxc", mdiscrxc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdiscrxc);
  gtk_table_attach (GTK_TABLE (table5), mdiscrxc, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_combo_set_value_in_list (GTK_COMBO (mdiscrxc), TRUE, FALSE);
  gtk_combo_set_case_sensitive (GTK_COMBO (mdiscrxc), TRUE);
  mdiscrxc_items = g_list_append (mdiscrxc_items, _("Normal"));
  mdiscrxc_items = g_list_append (mdiscrxc_items, _("TxData"));
  gtk_combo_set_popdown_strings (GTK_COMBO (mdiscrxc), mdiscrxc_items);
  g_list_free (mdiscrxc_items);

  mdiscrxcentry = GTK_COMBO (mdiscrxc)->entry;
  gtk_widget_ref (mdiscrxcentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdiscrxcentry", mdiscrxcentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdiscrxcentry);
  gtk_widget_set_usize (mdiscrxcentry, 60, -2);
  gtk_tooltips_set_tip (tooltips, mdiscrxcentry, _("selects the output signal if the internal FSK mode is used"), NULL);
  gtk_entry_set_text (GTK_ENTRY (mdiscrxcentry), _("Normal"));

  mdisctxc = gtk_combo_new ();
  gtk_widget_ref (mdisctxc);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisctxc", mdisctxc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisctxc);
  gtk_table_attach (GTK_TABLE (table5), mdisctxc, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_combo_set_value_in_list (GTK_COMBO (mdisctxc), TRUE, FALSE);
  gtk_combo_set_case_sensitive (GTK_COMBO (mdisctxc), TRUE);
  mdisctxc_items = g_list_append (mdisctxc_items, _("Normal"));
  mdisctxc_items = g_list_append (mdisctxc_items, _("TxData"));
  gtk_combo_set_popdown_strings (GTK_COMBO (mdisctxc), mdisctxc_items);
  g_list_free (mdisctxc_items);

  mdisctxcentry = GTK_COMBO (mdisctxc)->entry;
  gtk_widget_ref (mdisctxcentry);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "mdisctxcentry", mdisctxcentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (mdisctxcentry);
  gtk_widget_set_usize (mdisctxcentry, 60, -2);
  gtk_tooltips_set_tip (tooltips, mdisctxcentry, _("selects the output signal if the internal FSK mode is used"), NULL);
  gtk_entry_set_text (GTK_ENTRY (mdisctxcentry), _("Normal"));

  label21 = gtk_label_new (_("Modem Disc"));
  gtk_widget_ref (label21);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "label21", label21,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label21);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (confignotebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (confignotebook), 4), label21);

  hbuttonbox8 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox8);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "hbuttonbox8", hbuttonbox8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox8);
  gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox8, FALSE, FALSE, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox8), GTK_BUTTONBOX_SPREAD);

  configok = gtk_button_new_with_label (_("OK"));
  gtk_widget_ref (configok);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "configok", configok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (configok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), configok);
  GTK_WIDGET_SET_FLAGS (configok, GTK_CAN_DEFAULT);

  configcancel = gtk_button_new_with_label (_("Cancel"));
  gtk_widget_ref (configcancel);
  gtk_object_set_data_full (GTK_OBJECT (configwindow), "configcancel", configcancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (configcancel);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), configcancel);
  GTK_WIDGET_SET_FLAGS (configcancel, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (configwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_configwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (configok), "clicked",
                      GTK_SIGNAL_FUNC (on_configwindowok_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (configcancel), "clicked",
                      GTK_SIGNAL_FUNC (on_configwindowcancel_clicked),
                      NULL);

  gtk_object_set_data (GTK_OBJECT (configwindow), "tooltips", tooltips);

  return configwindow;
}

GtkWidget*
create_dtmfwindow (void)
{
  GtkWidget *dtmfwindow;
  GtkWidget *vbox4;
  GtkWidget *frame4;
  GtkWidget *hbox2;
  GtkWidget *dtmfentry;
  GtkWidget *buttoncleardtmf;
  GtkWidget *frame5;
  GtkWidget *table4;
  GtkWidget *dtmf8;
  GtkWidget *dtmf9;
  GtkWidget *dtmfa;
  GtkWidget *dtmf4;
  GtkWidget *dtmf5;
  GtkWidget *dtmf6;
  GtkWidget *dtmfb;
  GtkWidget *dtmf1;
  GtkWidget *dtmf2;
  GtkWidget *dtmf3;
  GtkWidget *dtmfc;
  GtkWidget *dtmfe;
  GtkWidget *dtmf0;
  GtkWidget *dtmff;
  GtkWidget *dtmfd;
  GtkWidget *dtmf7;

  dtmfwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (dtmfwindow), "dtmfwindow", dtmfwindow);
  gtk_widget_set_events (dtmfwindow, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
  gtk_window_set_title (GTK_WINDOW (dtmfwindow), _("DTMF Keypad"));
  gtk_window_set_wmclass (GTK_WINDOW (dtmfwindow), "baycomusb", "baycomusb");

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox4);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "vbox4", vbox4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox4);
  gtk_container_add (GTK_CONTAINER (dtmfwindow), vbox4);

  frame4 = gtk_frame_new (_("Keys transmitted"));
  gtk_widget_ref (frame4);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "frame4", frame4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame4);
  gtk_box_pack_start (GTK_BOX (vbox4), frame4, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame4), 5);
  gtk_frame_set_label_align (GTK_FRAME (frame4), 0.01, 0.5);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (frame4), hbox2);

  dtmfentry = gtk_entry_new ();
  gtk_widget_ref (dtmfentry);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmfentry", dtmfentry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmfentry);
  gtk_box_pack_start (GTK_BOX (hbox2), dtmfentry, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (dtmfentry), FALSE);

  buttoncleardtmf = gtk_button_new_with_label (_("Clear"));
  gtk_widget_ref (buttoncleardtmf);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "buttoncleardtmf", buttoncleardtmf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (buttoncleardtmf);
  gtk_box_pack_start (GTK_BOX (hbox2), buttoncleardtmf, FALSE, FALSE, 0);
  gtk_widget_set_usize (buttoncleardtmf, 50, -2);

  frame5 = gtk_frame_new (_("Keypad"));
  gtk_widget_ref (frame5);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "frame5", frame5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame5);
  gtk_box_pack_start (GTK_BOX (vbox4), frame5, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame5), 5);
  gtk_frame_set_label_align (GTK_FRAME (frame5), 0.01, 0.5);

  table4 = gtk_table_new (4, 4, FALSE);
  gtk_widget_ref (table4);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "table4", table4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table4);
  gtk_container_add (GTK_CONTAINER (frame5), table4);

  dtmf8 = gtk_button_new_with_label (_("8"));
  gtk_widget_ref (dtmf8);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf8", dtmf8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf8);
  gtk_table_attach (GTK_TABLE (table4), dtmf8, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf9 = gtk_button_new_with_label (_("9"));
  gtk_widget_ref (dtmf9);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf9", dtmf9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf9);
  gtk_table_attach (GTK_TABLE (table4), dtmf9, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmfa = gtk_button_new_with_label (_("A"));
  gtk_widget_ref (dtmfa);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmfa", dtmfa,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmfa);
  gtk_table_attach (GTK_TABLE (table4), dtmfa, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf4 = gtk_button_new_with_label (_("4"));
  gtk_widget_ref (dtmf4);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf4", dtmf4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf4);
  gtk_table_attach (GTK_TABLE (table4), dtmf4, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf5 = gtk_button_new_with_label (_("5"));
  gtk_widget_ref (dtmf5);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf5", dtmf5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf5);
  gtk_table_attach (GTK_TABLE (table4), dtmf5, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf6 = gtk_button_new_with_label (_("6"));
  gtk_widget_ref (dtmf6);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf6", dtmf6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf6);
  gtk_table_attach (GTK_TABLE (table4), dtmf6, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmfb = gtk_button_new_with_label (_("B"));
  gtk_widget_ref (dtmfb);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmfb", dtmfb,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmfb);
  gtk_table_attach (GTK_TABLE (table4), dtmfb, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf1 = gtk_button_new_with_label (_("1"));
  gtk_widget_ref (dtmf1);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf1", dtmf1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf1);
  gtk_table_attach (GTK_TABLE (table4), dtmf1, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf2 = gtk_button_new_with_label (_("2"));
  gtk_widget_ref (dtmf2);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf2", dtmf2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf2);
  gtk_table_attach (GTK_TABLE (table4), dtmf2, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf3 = gtk_button_new_with_label (_("3"));
  gtk_widget_ref (dtmf3);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf3", dtmf3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf3);
  gtk_table_attach (GTK_TABLE (table4), dtmf3, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmfc = gtk_button_new_with_label (_("C"));
  gtk_widget_ref (dtmfc);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmfc", dtmfc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmfc);
  gtk_table_attach (GTK_TABLE (table4), dtmfc, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmfe = gtk_button_new_with_label (_("*"));
  gtk_widget_ref (dtmfe);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmfe", dtmfe,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmfe);
  gtk_table_attach (GTK_TABLE (table4), dtmfe, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf0 = gtk_button_new_with_label (_("0"));
  gtk_widget_ref (dtmf0);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf0", dtmf0,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf0);
  gtk_table_attach (GTK_TABLE (table4), dtmf0, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmff = gtk_button_new_with_label (_("#"));
  gtk_widget_ref (dtmff);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmff", dtmff,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmff);
  gtk_table_attach (GTK_TABLE (table4), dtmff, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmfd = gtk_button_new_with_label (_("D"));
  gtk_widget_ref (dtmfd);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmfd", dtmfd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmfd);
  gtk_table_attach (GTK_TABLE (table4), dtmfd, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  dtmf7 = gtk_button_new_with_label (_("7"));
  gtk_widget_ref (dtmf7);
  gtk_object_set_data_full (GTK_OBJECT (dtmfwindow), "dtmf7", dtmf7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (dtmf7);
  gtk_table_attach (GTK_TABLE (table4), dtmf7, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  gtk_signal_connect (GTK_OBJECT (dtmfwindow), "key_press_event",
                      GTK_SIGNAL_FUNC (on_dtmfwindow_key_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (dtmfwindow), "key_release_event",
                      GTK_SIGNAL_FUNC (on_dtmfwindow_key_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (dtmfwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_dtmfwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (buttoncleardtmf), "clicked",
                      GTK_SIGNAL_FUNC (on_dtmfclear_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (dtmf8), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x18);
  gtk_signal_connect (GTK_OBJECT (dtmf8), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x08);
  gtk_signal_connect (GTK_OBJECT (dtmf9), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x19);
  gtk_signal_connect (GTK_OBJECT (dtmf9), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x09);
  gtk_signal_connect (GTK_OBJECT (dtmfa), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x1a);
  gtk_signal_connect (GTK_OBJECT (dtmfa), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x0a);
  gtk_signal_connect (GTK_OBJECT (dtmf4), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x14);
  gtk_signal_connect (GTK_OBJECT (dtmf4), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x04);
  gtk_signal_connect (GTK_OBJECT (dtmf5), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x15);
  gtk_signal_connect (GTK_OBJECT (dtmf5), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x05);
  gtk_signal_connect (GTK_OBJECT (dtmf6), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x16);
  gtk_signal_connect (GTK_OBJECT (dtmf6), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x06);
  gtk_signal_connect (GTK_OBJECT (dtmfb), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x1b);
  gtk_signal_connect (GTK_OBJECT (dtmfb), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x0b);
  gtk_signal_connect (GTK_OBJECT (dtmf1), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x11);
  gtk_signal_connect (GTK_OBJECT (dtmf1), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x01);
  gtk_signal_connect (GTK_OBJECT (dtmf2), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x12);
  gtk_signal_connect (GTK_OBJECT (dtmf2), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x02);
  gtk_signal_connect (GTK_OBJECT (dtmf3), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x13);
  gtk_signal_connect (GTK_OBJECT (dtmf3), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x03);
  gtk_signal_connect (GTK_OBJECT (dtmfc), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x1c);
  gtk_signal_connect (GTK_OBJECT (dtmfc), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x0c);
  gtk_signal_connect (GTK_OBJECT (dtmfe), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x1e);
  gtk_signal_connect (GTK_OBJECT (dtmfe), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x0e);
  gtk_signal_connect (GTK_OBJECT (dtmf0), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x10);
  gtk_signal_connect (GTK_OBJECT (dtmf0), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x00);
  gtk_signal_connect (GTK_OBJECT (dtmff), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x1f);
  gtk_signal_connect (GTK_OBJECT (dtmff), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x0f);
  gtk_signal_connect (GTK_OBJECT (dtmfd), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x1d);
  gtk_signal_connect (GTK_OBJECT (dtmfd), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x0d);
  gtk_signal_connect (GTK_OBJECT (dtmf7), "pressed",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x17);
  gtk_signal_connect (GTK_OBJECT (dtmf7), "released",
                      GTK_SIGNAL_FUNC (on_dtmf_key),
                      (gpointer)0x07);

  return dtmfwindow;
}

GtkWidget*
create_spkscopewindow (void)
{
  GtkWidget *spkscopewindow;
  GtkWidget *scope;

  spkscopewindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (spkscopewindow), "spkscopewindow", spkscopewindow);
  gtk_window_set_title (GTK_WINDOW (spkscopewindow), _("Baycom USB Speaker Scope"));
  gtk_window_set_wmclass (GTK_WINDOW (spkscopewindow), "baycomusb", "baycomusb");

  scope = scope_new ("scope", NULL, NULL, 128, 0);
  gtk_widget_ref (scope);
  gtk_object_set_data_full (GTK_OBJECT (spkscopewindow), "scope", scope,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scope);
  gtk_container_add (GTK_CONTAINER (spkscopewindow), scope);
  gtk_widget_set_usize (scope, 512, 256);
  GTK_WIDGET_UNSET_FLAGS (scope, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (scope, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (spkscopewindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_spkscopewindow_delete_event),
                      NULL);

  return spkscopewindow;
}

GtkWidget*
create_spkspectrumwindow (void)
{
  GtkWidget *spkspectrumwindow;
  GtkWidget *spec;

  spkspectrumwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (spkspectrumwindow), "spkspectrumwindow", spkspectrumwindow);
  gtk_window_set_title (GTK_WINDOW (spkspectrumwindow), _("Baycom USB Speaker Spectrum"));
  gtk_window_set_wmclass (GTK_WINDOW (spkspectrumwindow), "baycomusb", "baycomusb");

  spec = spectrum_new ("spec", NULL, NULL, 256, 0);
  gtk_widget_ref (spec);
  gtk_object_set_data_full (GTK_OBJECT (spkspectrumwindow), "spec", spec,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spec);
  gtk_container_add (GTK_CONTAINER (spkspectrumwindow), spec);
  gtk_widget_set_usize (spec, 512, 256);
  GTK_WIDGET_UNSET_FLAGS (spec, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (spec, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (spkspectrumwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_spkspectrumwindow_delete_event),
                      NULL);

  return spkspectrumwindow;
}

GtkWidget*
create_micscopewindow (void)
{
  GtkWidget *micscopewindow;
  GtkWidget *scope;

  micscopewindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (micscopewindow), "micscopewindow", micscopewindow);
  gtk_window_set_title (GTK_WINDOW (micscopewindow), _("Baycom USB Microphone Scope"));
  gtk_window_set_wmclass (GTK_WINDOW (micscopewindow), "baycomusb", "baycomusb");

  scope = scope_new ("scope", NULL, NULL, 128, 0);
  gtk_widget_ref (scope);
  gtk_object_set_data_full (GTK_OBJECT (micscopewindow), "scope", scope,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scope);
  gtk_container_add (GTK_CONTAINER (micscopewindow), scope);
  gtk_widget_set_usize (scope, 512, 256);
  GTK_WIDGET_UNSET_FLAGS (scope, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (scope, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (micscopewindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_micscopewindow_delete_event),
                      NULL);

  return micscopewindow;
}

GtkWidget*
create_micspectrumwindow (void)
{
  GtkWidget *micspectrumwindow;
  GtkWidget *spec;

  micspectrumwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (micspectrumwindow), "micspectrumwindow", micspectrumwindow);
  gtk_window_set_title (GTK_WINDOW (micspectrumwindow), _("Baycom USB Microphone Spectrum"));
  gtk_window_set_wmclass (GTK_WINDOW (micspectrumwindow), "baycomusb", "baycomusb");

  spec = spectrum_new ("spec", NULL, NULL, 256, 0);
  gtk_widget_ref (spec);
  gtk_object_set_data_full (GTK_OBJECT (micspectrumwindow), "spec", spec,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spec);
  gtk_container_add (GTK_CONTAINER (micspectrumwindow), spec);
  gtk_widget_set_usize (spec, 512, 256);
  GTK_WIDGET_UNSET_FLAGS (spec, GTK_CAN_FOCUS);
  GTK_WIDGET_UNSET_FLAGS (spec, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (micspectrumwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_micspectrumwindow_delete_event),
                      NULL);

  return micspectrumwindow;
}

GtkWidget*
create_paramwindow (void)
{
  GtkWidget *paramwindow;
  GtkWidget *vbox10;
  GtkWidget *table9;
  GtkWidget *paramenablepttpkt;
  GtkWidget *label151;
  GtkWidget *hbuttonbox9;
  GtkWidget *paramok;
  GtkWidget *paramcancel;

  paramwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (paramwindow), "paramwindow", paramwindow);
  gtk_window_set_title (GTK_WINDOW (paramwindow), _("Baycom USB Adapter Parameters"));
  gtk_window_set_wmclass (GTK_WINDOW (paramwindow), "baycomusb", "baycomusb");

  vbox10 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox10);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "vbox10", vbox10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox10);
  gtk_container_add (GTK_CONTAINER (paramwindow), vbox10);

  table9 = gtk_table_new (1, 3, FALSE);
  gtk_widget_ref (table9);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "table9", table9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table9);
  gtk_box_pack_start (GTK_BOX (vbox10), table9, TRUE, TRUE, 0);

  paramenablepttpkt = gtk_check_button_new_with_label ("");
  gtk_widget_ref (paramenablepttpkt);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "paramenablepttpkt", paramenablepttpkt,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (paramenablepttpkt);
  gtk_table_attach (GTK_TABLE (table9), paramenablepttpkt, 1, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label151 = gtk_label_new (_("Enable PTT for Packet"));
  gtk_widget_ref (label151);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "label151", label151,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label151);
  gtk_table_attach (GTK_TABLE (table9), label151, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label151), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label151), 5, 0);

  hbuttonbox9 = gtk_hbutton_box_new ();
  gtk_widget_ref (hbuttonbox9);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "hbuttonbox9", hbuttonbox9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbuttonbox9);
  gtk_box_pack_start (GTK_BOX (vbox10), hbuttonbox9, FALSE, TRUE, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox9), GTK_BUTTONBOX_SPREAD);

  paramok = gtk_button_new_with_label (_("OK"));
  gtk_widget_ref (paramok);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "paramok", paramok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (paramok);
  gtk_container_add (GTK_CONTAINER (hbuttonbox9), paramok);
  GTK_WIDGET_SET_FLAGS (paramok, GTK_CAN_DEFAULT);

  paramcancel = gtk_button_new_with_label (_("Cancel"));
  gtk_widget_ref (paramcancel);
  gtk_object_set_data_full (GTK_OBJECT (paramwindow), "paramcancel", paramcancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (paramcancel);
  gtk_container_add (GTK_CONTAINER (hbuttonbox9), paramcancel);
  GTK_WIDGET_SET_FLAGS (paramcancel, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (paramwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_paramwindow_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (paramok), "clicked",
                      GTK_SIGNAL_FUNC (on_paramwindowok_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (paramcancel), "clicked",
                      GTK_SIGNAL_FUNC (on_paramwindowcancel_clicked),
                      NULL);

  return paramwindow;
}

GtkWidget*
create_audiopwrwindow (void)
{
  GtkWidget *audiopwrwindow;
  GtkWidget *hbox5;
  GtkWidget *frame7;
  GtkWidget *hbox6;
  GtkWidget *frame9;
  GtkWidget *audiomicsig;
  GtkWidget *frame8;
  GtkWidget *hbox7;
  GtkWidget *frame10;
  GtkWidget *audiospksig;
  GtkWidget *frame11;
  GtkWidget *audiospknoise;

  audiopwrwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (audiopwrwindow), "audiopwrwindow", audiopwrwindow);
  gtk_window_set_title (GTK_WINDOW (audiopwrwindow), _("Baycom USB Audio Power Meters"));
  gtk_window_set_wmclass (GTK_WINDOW (audiopwrwindow), "baycomusb", "baycomusb");

  hbox5 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox5);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "hbox5", hbox5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox5);
  gtk_container_add (GTK_CONTAINER (audiopwrwindow), hbox5);

  frame7 = gtk_frame_new (_("Mic"));
  gtk_widget_ref (frame7);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "frame7", frame7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame7);
  gtk_box_pack_start (GTK_BOX (hbox5), frame7, TRUE, TRUE, 0);

  hbox6 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox6);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "hbox6", hbox6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox6);
  gtk_container_add (GTK_CONTAINER (frame7), hbox6);

  frame9 = gtk_frame_new (_("S"));
  gtk_widget_ref (frame9);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "frame9", frame9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame9);
  gtk_box_pack_start (GTK_BOX (hbox6), frame9, TRUE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame9), 0.5, 0.5);

  audiomicsig = gtk_progress_bar_new ();
  gtk_widget_ref (audiomicsig);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "audiomicsig", audiomicsig,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audiomicsig);
  gtk_container_add (GTK_CONTAINER (frame9), audiomicsig);
  gtk_progress_configure (GTK_PROGRESS (audiomicsig), -40, -40, 0);
  gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (audiomicsig), GTK_PROGRESS_BOTTOM_TO_TOP);

  frame8 = gtk_frame_new (_("Spkr"));
  gtk_widget_ref (frame8);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "frame8", frame8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame8);
  gtk_box_pack_start (GTK_BOX (hbox5), frame8, TRUE, TRUE, 0);

  hbox7 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox7);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "hbox7", hbox7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox7);
  gtk_container_add (GTK_CONTAINER (frame8), hbox7);

  frame10 = gtk_frame_new (_("S"));
  gtk_widget_ref (frame10);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "frame10", frame10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame10);
  gtk_box_pack_start (GTK_BOX (hbox7), frame10, TRUE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame10), 0.5, 0.5);

  audiospksig = gtk_progress_bar_new ();
  gtk_widget_ref (audiospksig);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "audiospksig", audiospksig,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audiospksig);
  gtk_container_add (GTK_CONTAINER (frame10), audiospksig);
  gtk_progress_configure (GTK_PROGRESS (audiospksig), -40, -40, 0);
  gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (audiospksig), GTK_PROGRESS_BOTTOM_TO_TOP);

  frame11 = gtk_frame_new (_("N"));
  gtk_widget_ref (frame11);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "frame11", frame11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame11);
  gtk_box_pack_start (GTK_BOX (hbox7), frame11, TRUE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame11), 0.5, 0.5);

  audiospknoise = gtk_progress_bar_new ();
  gtk_widget_ref (audiospknoise);
  gtk_object_set_data_full (GTK_OBJECT (audiopwrwindow), "audiospknoise", audiospknoise,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (audiospknoise);
  gtk_container_add (GTK_CONTAINER (frame11), audiospknoise);
  gtk_progress_configure (GTK_PROGRESS (audiospknoise), -40, -40, 0);
  gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (audiospknoise), GTK_PROGRESS_BOTTOM_TO_TOP);

  gtk_signal_connect (GTK_OBJECT (audiopwrwindow), "delete_event",
                      GTK_SIGNAL_FUNC (on_audiopwrwindow_delete_event),
                      NULL);

  return audiopwrwindow;
}

